@@ -457,10 +457,13 @@ static void register_panel_action_edit_paste(GtkMenuItem *menuitem, gpointer
 {
 struct register_panel_data *data = user_data;
 GList *list;
+gboolean istoday = FALSE;
 
 	DB( g_print("\n[register] paste normal\n") );
-	
-	DB( g_print(" paste %d - as today=%d\n", (gint)g_queue_get_length(data->q_txn_clip), (gint) (menuitem == data->MI_pastet)) );
+
+	istoday = ( (gpointer)menuitem == (gpointer)data->MI_pastet ) ? TRUE : FALSE;
+
+	DB( g_print(" paste %d - as today=%d\n", (gint)g_queue_get_length(data->q_txn_clip), istoday) );
 	
 	list = g_queue_peek_head_link(data->q_txn_clip);
 	while (list != NULL)
@@ -470,7 +473,7 @@ GList *list;
 		
 		DB( g_print(" paste txn %p - '%.2f' '%s'\n", item, item->amount, item->memo) );
 
-		if( (gpointer)menuitem == (gpointer)data->MI_pastet )
+		if( istoday == TRUE )
 			item->date = GLOBALS->today;
 
 		add_txn = transaction_add(GTK_WINDOW(data->window), item);
@@ -547,27 +550,38 @@ struct register_panel_data *data = user_data;
 static void register_panel_export_csv(GtkWidget *widget, gpointer user_data)
 {
 struct register_panel_data *data;
-gchar *filename = NULL;
+gchar *name, *filepath;
 GString *node;
 GIOChannel *io;
+gboolean detailsplit;
 
 	DB( g_print("\n[register] export csv\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	if( ui_file_chooser_csv(GTK_WINDOW(data->window), GTK_FILE_CHOOSER_ACTION_SAVE, &filename, NULL) == TRUE )
+	name = g_strdup_printf("%s.csv", (data->showall == TRUE) ? GLOBALS->owner :data->acc->name);
+
+	filepath = g_build_filename(PREFS->path_export, name, NULL);
+
+	if( ui_dialog_export_csv(GTK_WINDOW(data->window), &filepath, &detailsplit, data->showall) == GTK_RESPONSE_ACCEPT )
 	{
-		DB( g_print(" + filename is %s\n", filename) );
-		io = g_io_channel_new_file(filename, "w", NULL);
+		DB( g_printf(" filename is'%s'\n", filepath) );
+		io = g_io_channel_new_file(filepath, "w", NULL);
 		if(io != NULL)
 		{
-			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_ope), FALSE);
+			//TODO: add showall et detailsplit here
+			//+ handle it
+			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_ope), FALSE, detailsplit, data->showall);
+
 			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 			g_io_channel_unref (io);
 			g_string_free(node, TRUE);
 		}
-		g_free( filename );
 	}
+
+	g_free(filepath);
+	g_free(name);
+
 }
 
 
@@ -909,6 +923,7 @@ gint status;
 static void register_panel_cb_filter_reset(GtkWidget *widget, gpointer user_data)
 {
 struct register_panel_data *data;
+gint dspstatus;
 
 	DB( g_print("\n[register] filter_reset\n") );
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
@@ -933,13 +948,18 @@ struct register_panel_data *data;
 
 	DB( g_print(" - set range : %d\n", data->filter->range) );
 	DB( g_print(" - set type  : %d\n", data->filter->type) );
-	DB( g_print(" - set status: %d\n", data->filter->rawstatus) );
+	DB( g_print(" - set status: %d\n", data->filter->status) );
 
 	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), data->filter->range);
+	
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_type), data->filter->type);
-	//# #1873324 register status quick filter do not reset 
+	//#1873324 register status quick filter do not reset 
 	//gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_status), data->filter->rawstatus);
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_status), data->filter->status);
+	//#1878483 status with hidereconciled shows reconciled (due to filter !reconciled internal
+	dspstatus = data->filter->status;
+	if( (dspstatus == FLT_STATUS_RECONCILED) && (data->filter->option[FILTER_STATUS] == 2) )
+		dspstatus = FLT_STATUS_UNRECONCILED;
+	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_status), dspstatus);
 
 	g_signal_handler_unblock(data->CY_status, data->handler_id[HID_STATUS]);
 	g_signal_handler_unblock(data->CY_type, data->handler_id[HID_TYPE]);
@@ -1892,7 +1912,8 @@ gint count = 0;
 		hb_widget_visible(data->MI_exportpdf, visible);
 		hb_widget_visible(data->MI_print, visible);
 		hb_widget_visible(data->MI_exportqif, visible);
-		hb_widget_visible(data->MI_exportcsv, visible);
+		//5.4.3 enabled 
+		//hb_widget_visible(data->MI_exportcsv, visible);
 		//tools
 		hb_widget_visible(data->MI_markdup, visible);
 		hb_widget_visible(data->MI_chkintxfer, visible);
@@ -2197,6 +2218,21 @@ struct WinGeometry *wg;
 }
 
 
+static gboolean register_panel_cb_search_focus_in_event(GtkWidget *widget, GdkEventFocus *event, gpointer user_data)
+{
+struct register_panel_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("\n[register] search focus-in event\n") );
+
+	
+	gtk_tree_selection_unselect_all(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_ope)));
+
+	return FALSE;
+}
+
+
 //beta
 static gboolean register_panel_cb_focus_in_event(GtkWidget *widget, GdkEventFocus *event, gpointer user_data)
 {
@@ -2677,8 +2713,6 @@ GtkWidget *treeview, *label, *widget, *image;
 	gtk_widget_set_halign(widget, GTK_ALIGN_END);
 	gtk_grid_attach (GTK_GRID(table), widget, 11, 0, 1, 1);
 
-	data->handler_id[HID_SEARCH] = g_signal_connect (data->ST_search, "search-changed", G_CALLBACK (quick_search_text_changed_cb), data);
-
 	/* test */
 	table = gtk_grid_new();
 	gtk_grid_set_row_spacing (GTK_GRID (table), SPACING_SMALL);
@@ -2832,6 +2866,10 @@ GtkWidget *treeview, *label, *widget, *image;
 	
 	g_signal_connect (data->CM_minor , "toggled", G_CALLBACK (register_panel_toggle_minor), NULL);
 	
+	data->handler_id[HID_SEARCH] = g_signal_connect (data->ST_search, "search-changed", G_CALLBACK (quick_search_text_changed_cb), data);
+	//#1879451 deselect all when quicksearch has the focus (to prevent delete)
+	g_signal_connect (data->ST_search, "focus-in-event", G_CALLBACK (register_panel_cb_search_focus_in_event), NULL);
+	
 	g_signal_connect (G_OBJECT (data->BT_add   ), "clicked", G_CALLBACK (register_panel_action_add), (gpointer)data);
 	g_signal_connect (G_OBJECT (data->BT_herit ), "clicked", G_CALLBACK (register_panel_action_inherit), (gpointer)data);
 	g_signal_connect (G_OBJECT (data->BT_edit  ), "clicked", G_CALLBACK (register_panel_action_edit), (gpointer)data);
