@@ -448,6 +448,7 @@ struct hbfile_data *data = g_object_get_data(G_OBJECT(GLOBALS->mainwindow), "ins
 		//ui_mainwindow_action_toggle_minor(GTK_CHECK_MENU_ITEM(data->MI_eurominor), NULL);
 	}
 
+	homebank_pref_apply ();
 	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_VISUAL+UF_REFRESHALL));
 }
 
@@ -1379,11 +1380,12 @@ gint flags;
 			gtk_toolbar_set_style(GTK_TOOLBAR(data->toolbar), PREFS->toolbar_style-1);
 
 		gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (data->LV_acc), PREFS->grid_lines);
-		gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (data->LV_upc), PREFS->grid_lines);
-		//TODO: should add txn listview here as well
-		//gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_acc));
-		//gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_upc));
+		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_acc));
 
+		gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (data->LV_upc), PREFS->grid_lines);
+		gtk_tree_view_columns_autosize (GTK_TREE_VIEW(data->LV_upc));
+
+		//TODO: should add txn listview here as well
 		DB( g_print(" - show toolbar=%d\n", PREFS->wal_toolbar) );
 		hb_widget_visible(data->toolbar, PREFS->wal_toolbar); 
 
@@ -1489,7 +1491,7 @@ gboolean retval = FALSE;
 	}
 	else
 	{
-		//todo: retval is useless and below should move to destroy
+		//TODO: retval is useless and below should move to destroy
 		retval = TRUE;
 		gtk_widget_destroy(data->LV_top);
 
@@ -1630,9 +1632,6 @@ void ui_mainwindow_recent_add (struct hbfile_data *data, const gchar *path)
 }
 
 
-
-
-
 enum
 {
 	TARGET_URI_LIST
