@@ -179,7 +179,11 @@ eval_date(GtkDateEntry *self)
 {
 GtkDateEntryPrivate *priv = self->priv;
 
+	DB( g_print(" pre %d %d %d\n", g_date_get_day(priv->date), g_date_get_month(priv->date), g_date_get_year(priv->date)) );
+
 	g_date_clamp(priv->date, &priv->mindate, &priv->maxdate);
+	DB( g_print(" min %d %d %d\n", g_date_get_day(&priv->mindate), g_date_get_month(&priv->mindate), g_date_get_year(&priv->mindate)) );
+	DB( g_print(" max %d %d %d\n", g_date_get_day(&priv->maxdate), g_date_get_month(&priv->maxdate), g_date_get_year(&priv->maxdate)) );
 	
 	update_text(self);
 	
@@ -190,6 +194,8 @@ GtkDateEntryPrivate *priv = self->priv;
 	}
 
 	priv->lastdate = g_date_get_julian(priv->date);
+
+	DB( g_print(" post %d %d %d\n", g_date_get_day(priv->date), g_date_get_month(priv->date), g_date_get_year(priv->date)) );
 }
 
 
@@ -205,10 +211,13 @@ const gchar *str;
 
 	//1) we parse the string according to the locale
 	g_date_set_parse (priv->date, str);
+	DB( g_print(" parsed '%s' %d %d %d\n", str, g_date_get_day(priv->date), g_date_get_month(priv->date), g_date_get_year(priv->date)) );
+
 	if(!g_date_valid(priv->date) || g_date_get_julian (priv->date) <= HB_MINDATE)
 	{
 		//2) give a try to tokens: day, day/month, month/day
 		hb_date_parse_tokens(priv->date, str);
+		DB( g_print(" tokened %d %d %d\n", g_date_get_day(priv->date), g_date_get_month(priv->date), g_date_get_year(priv->date)) );
 	}
 
 	//3) at last if date still invalid, put today's dateentry_signals
@@ -291,53 +300,47 @@ gtk_date_entry_cb_entry_key_pressed (GtkWidget *widget, GdkEventKey *event, gpoi
 {
 GtkDateEntry *dateentry = user_data;
 GtkDateEntryPrivate *priv = dateentry->priv;
+guint action;
 
-	DB( g_print("\n[dateentry] entry key pressed: state=%04x, keyval=%04x\n", event->state, event->keyval) );
+	DB( g_print("\n[dateentry] entry key pressed") );
 
-	if( event->keyval == GDK_KEY_Up )
+
+	DB( g_print(" state: %s %s\n", (event->state & GDK_SHIFT_MASK) ? "shift" : "", (event->state & GDK_CONTROL_MASK) ? "ctrl" : "" ) );
+	DB( g_print(" kyval: %s %s\n", (event->keyval == GDK_KEY_Up) ? "up" : "",  (event->keyval == GDK_KEY_Down) ? "down" : "") );
+
+	if( (event->type != GDK_KEY_PRESS) )
+		return FALSE;
+
+	//#1873643 preserve Up/Down (+ctrl) natural GTK focus change
+	if( (event->state & GDK_CONTROL_MASK) && !(event->state & GDK_SHIFT_MASK) )
+		return FALSE;
+
+	if( (event->keyval == GDK_KEY_Up) || (event->keyval == GDK_KEY_Down) )
 	{
-		if( !(event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK)) )
+		//let's bitwise key to an action-id
+		action = 0;
+		action |= (event->state & GDK_SHIFT_MASK)   ? 2 : 0;
+		action |= (event->state & GDK_CONTROL_MASK) ? 4 : 0;
+		action |= (event->keyval == GDK_KEY_Down)   ? 1 : 0;
+
+		DB( g_print(" action: %d\n", action) );
+
+		switch(action)
 		{
-			g_date_add_days (priv->date, 1);
-			eval_date(dateentry);
-		}
-		else
-		if( event->state & GDK_SHIFT_MASK )
-		{
-			g_date_add_months (priv->date, 1);
-			eval_date(dateentry);
-		}
-		else
-		if( event->state & GDK_CONTROL_MASK )
-		{
-			g_date_add_years (priv->date, 1);
-			eval_date(dateentry);
+			case 0: g_date_add_days (priv->date, 1); break;
+			case 1: g_date_subtract_days (priv->date, 1); break;
+			case 2:	g_date_add_months (priv->date, 1); break;
+			case 3:	g_date_subtract_months (priv->date, 1); break;
+			case 6:	g_date_add_years (priv->date, 1); break;
+			case 7:	g_date_subtract_years (priv->date, 1); break;
 		}
+
+		eval_date(dateentry);
+
+		//stop handlers
 		return TRUE;
 	}
-	else
-	if( event->keyval == GDK_KEY_Down )
-	{
-		if( !(event->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK)) )
-		{
-			g_date_subtract_days (priv->date, 1);
-			eval_date(dateentry);
-		}
-		else
-		if( event->state & GDK_SHIFT_MASK )
-		{
-			g_date_subtract_months (priv->date, 1);
-			eval_date(dateentry);
-		}
-		else
-		if( event->state & GDK_CONTROL_MASK )
-		{
-			g_date_subtract_years (priv->date, 1);
-			eval_date(dateentry);
-		}
-		return TRUE;
-	}
-
+	//propagate
 	return FALSE;
 }
 
