@@ -149,6 +149,31 @@ guint da_archive_length(void)
 }
 
 
+void da_archive_stats(gint *nbtpl, gint *nbsch)
+{
+GList *tmplist = g_list_first(GLOBALS->arc_list);
+gint nbt, nbs;
+
+	nbt = nbs = 0;
+	while (tmplist != NULL)
+	{
+	Archive *item = tmplist->data;
+
+		if(item->flags & OF_AUTO)
+			nbs++;
+		else
+			nbt++;
+
+		tmplist = g_list_next(tmplist);
+	}
+
+	if( nbtpl != NULL)
+		*nbtpl = nbt;
+	if( nbsch != NULL)
+		*nbsch = nbs;
+}
+
+
 /* append a fav with an existing key (from xml file only) */
 gboolean
 da_archive_append(Archive *item)
@@ -275,7 +300,8 @@ guint nbsplit;
 
 /* = = = = = = = = = = = = = = = = = = = = */
 
-Archive *da_archive_init_from_transaction(Archive *arc, Transaction *txn)
+//#1872140 don't prefix if not from register
+Archive *da_archive_init_from_transaction(Archive *arc, Transaction *txn, gboolean fromregister)
 {
 	DB( g_print("\n[scheduled] init from txn\n") );
 
@@ -291,8 +317,20 @@ Archive *da_archive_init_from_transaction(Archive *arc, Transaction *txn)
 	arc->kpay		= txn->kpay;
 	arc->kcat		= txn->kcat;
 
-	if(txn->memo != NULL)
-		arc->memo = g_strdup(txn->memo);
+	//5.3.3 prefixed with prefilled
+	//#1883063 **PREFILLED** only when fromregister==TRUE, test order was wrogn here
+	if( fromregister == FALSE )
+	{
+		if(txn->memo != NULL)
+			arc->memo = g_strdup(txn->memo);	
+	}
+	else
+	{
+		if(txn->memo != NULL)
+			arc->memo = g_strdup_printf("%s %s", _("**PREFILLED**"), txn->memo );
+		else
+			arc->memo = g_strdup(_("**PREFILLED**"));
+	}	
 
 	if(txn->info != NULL)
 		arc->info = g_strdup(txn->info);
@@ -536,7 +574,7 @@ GDate *today, *maxdate;
 
 	DB( g_print("\n[scheduled] date_get_post_max\n") );
 
-	//add until xx of the next month (excluded)
+	//add until xx of the each month (excluded)
 	if(GLOBALS->auto_smode == 0)	
 	{
 		DB( g_print(" - max is %d of next month\n", GLOBALS->auto_weekday) );
@@ -554,6 +592,7 @@ GDate *today, *maxdate;
 		g_date_free(maxdate);
 		g_date_free(today);
 	}
+	//add xx days in advance the current date
 	else
 	{
 		nbdays = GLOBALS->auto_nbdays;
