@@ -595,6 +595,7 @@ Category *parent;
 	if(cat)
 	{
 		cat->usage_count++;
+		cat->usage_catcount++;
 		if( cat->parent > 0 )
 		{
 			parent = da_cat_get(cat->parent);
@@ -621,6 +622,7 @@ guint i, nbsplit;
 	{
 	Category *entry = list->data;
 		entry->usage_count = 0;
+		entry->usage_catcount = 0;
 		list = g_list_next(list);
 	}
 	g_list_free(lcat);
@@ -703,12 +705,34 @@ guint i, nbsplit;
 
 }
 
+//#1875070 if srckey is a cat: any subcat should match as well
+static gboolean
+category_move_match(guint32 eltkey, guint32 srckey, gboolean dosubcat)
+{
+Category *cat = da_cat_get(eltkey);
+
+	if(cat)
+	{
+		if(!dosubcat)
+		{
+			if(cat->key == srckey)
+				return TRUE;
+		}	
+		else
+		{
+			if(cat->key == srckey || cat->parent == srckey)
+				return TRUE;
+		}
+	}
+	return FALSE;
+}
+
 
 void
-category_move(guint32 key1, guint32 key2)
+category_move(guint32 srckey, guint32 newkey, gboolean dosubcat)
 {
 GList *lst_acc, *lnk_acc;
-GList *lnk_txn;
+GList *lnk_txn, *lpay;
 GList *lrul, *list;
 guint i, nbsplit;
 
@@ -723,9 +747,11 @@ guint i, nbsplit;
 		{
 		Transaction *txn = lnk_txn->data;
 		
-			if(txn->kcat == key1)
+			//#1875070
+			//if(txn->kcat == srckey)
+			if( category_move_match(txn->kcat, srckey, dosubcat) )
 			{
-				txn->kcat = key2;
+				txn->kcat = newkey;
 				txn->flags |= OF_CHANGED;
 			}
 
@@ -735,9 +761,11 @@ guint i, nbsplit;
 			{
 			Split *split = da_splits_get(txn->splits, i);
 
-				if( split->kcat == key1 )
+				//#1875070
+				//if( split->kcat == srckey )
+				if( category_move_match(split->kcat, srckey, dosubcat) )
 				{
-					split->kcat = key2;
+					split->kcat = newkey;
 					txn->flags |= OF_CHANGED;
 				}
 			}
@@ -754,21 +782,41 @@ guint i, nbsplit;
 	while (list != NULL)
 	{
 	Archive *entry = list->data;
-		if(entry->kcat == key1)
+	
+		//#1875070
+		//if(entry->kcat == srckey)
+		if( category_move_match(entry->kcat, srckey, dosubcat) )
 		{
-			entry->kcat = key2;
+			entry->kcat = newkey;
 		}
 		list = g_list_next(list);
 	}
 
+	//fix 5.4.2 missed payee here
+	lpay = list = g_hash_table_get_values(GLOBALS->h_pay);
+	while (list != NULL)
+	{
+	Payee *entry = list->data;
+
+		if( category_move_match(entry->kcat, srckey, dosubcat) )
+		{
+			entry->kcat = newkey;
+		}
+		list = g_list_next(list);
+	}
+	g_list_free(lpay);
+	
+
 	lrul = list = g_hash_table_get_values(GLOBALS->h_rul);
 	while (list != NULL)
 	{
 	Assign *entry = list->data;
 
-		if(entry->kcat == key1)
+		//#1875070
+		//if(entry->kcat == srckey)
+		if( category_move_match(entry->kcat, srckey, dosubcat) )
 		{
-			entry->kcat = key2;
+			entry->kcat = newkey;
 		}
 		list = g_list_next(list);
 	}
