@@ -36,7 +36,8 @@ struct _category
 	/* unsaved datas */
 	gchar		*fullname;
 	gboolean	flt_select;
-	guint		usage_count;
+	guint		usage_count;	//cat+subcat usage
+	guint		usage_catcount;	//cat usage only
 };
 
 #define GF_SUB		(1<<0)		//? useful as we can check item->parent= 0
@@ -75,7 +76,7 @@ guint32 category_report_id(guint32 key, gboolean subcat);
 void category_delete_unused(void);
 void category_fill_usage(void);
 
-void category_move(guint32 key1, guint32 key2);
+void category_move(guint32 srckey, guint32 newkey, gboolean dosubcat);
 gboolean category_rename(Category *item, const gchar *newname);
 
 gchar *category_find_preset(gchar **lang);
