@@ -49,13 +49,13 @@ extern guint n_iso4217cur;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-void 
+void
 da_cur_free(Currency *item)
 {
-	DB( g_print("da_cur_free\n") );
+	DB( g_print("\n[da_cur] free\n") );
 	if(item != NULL)
 	{
-		DB( g_print(" => %d, %s\n", item->key, item->iso_code) );
+		DB( g_print(" %d, %s\n", item->key, item->iso_code) );
 
 		g_free(item->name);
 		g_free(item->iso_code);
@@ -71,7 +71,7 @@ da_cur_free(Currency *item)
 Currency *
 da_cur_malloc(void)
 {
-	DB( g_print("da_cur_malloc\n") );
+	DB( g_print("\n[da_cur] malloc\n") );
 	return g_malloc0(sizeof(Currency));
 }
 
@@ -79,7 +79,7 @@ da_cur_malloc(void)
 void
 da_cur_destroy(void)
 {
-	DB( g_print("da_cur_destroy\n") );
+	DB( g_print("\n[da_cur] destroy\n") );
 	g_hash_table_destroy(GLOBALS->h_cur);
 }
 
@@ -87,8 +87,8 @@ void
 da_cur_new(void)
 {
 Currency4217 *curfmt;
-	
-	DB( g_print("da_cur_new\n") );
+
+	DB( g_print("\n[da_cur] new\n") );
 	GLOBALS->h_cur = g_hash_table_new_full(g_int_hash, g_int_equal, (GDestroyNotify)g_free, (GDestroyNotify)da_cur_free);
 
 	// insert default base currency
@@ -98,7 +98,7 @@ Currency4217 *curfmt;
 
 	if(curfmt)
 	{
-	DB( g_printf("curfmt %p\n", curfmt) );
+	DB( g_printf(" curfmt %p\n", curfmt) );
 
 		currency_add_from_user(curfmt);
 	}
@@ -140,13 +140,13 @@ da_cur_length(void)
 gboolean
 da_cur_delete(guint32 key)
 {
-	DB( g_print("da_cur_delete %d\n", key) );
+	DB( g_print("\n[da_cur] delete %d\n", key) );
 
 	return g_hash_table_remove(GLOBALS->h_cur, &key);
 }
 
 
-void 
+void
 da_cur_init_from4217(Currency *cur, Currency4217 *curfmt)
 {
 	cur->symbol        = g_strdup(curfmt->curr_symbol);
@@ -161,7 +161,9 @@ da_cur_init_from4217(Currency *cur, Currency4217 *curfmt)
 void
 da_cur_initformat(Currency *item)
 {
-	DB( g_print("init currency %s, %d \n", item->symbol, item->frac_digits) );
+	DB( g_print("\n[da_cur] init format\n") );
+
+	DB( g_print(" k:%d iso:'%s' symbol:'%s' digit:%d\n", item->key, item->iso_code, item->symbol, item->frac_digits) );
 
 	// for formatd
 	g_snprintf(item->format , 8-1, "%%.%df", item->frac_digits);
@@ -171,8 +173,8 @@ da_cur_initformat(Currency *item)
 	else
 		g_snprintf(item->monfmt , 32-1, "%%s %s", item->symbol);
 
-	DB( g_print("fmt '%s'\n", item->format) );
-	DB( g_print("monfmt '%s'\n", item->monfmt) );
+	DB( g_print(" numfmt '%s'\n", item->format) );
+	DB( g_print(" monfmt '%s'\n", item->monfmt) );
 }
 
 
@@ -181,14 +183,14 @@ da_cur_insert(Currency *item)
 {
 guint32 *new_key;
 
-	DB( g_print("da_cur_insert\n") );
+	DB( g_print("\n[da_cur] insert\n") );
 
 	new_key = g_new0(guint32, 1);
 	*new_key = item->key;
-	g_hash_table_insert(GLOBALS->h_cur, new_key, item);	
+	g_hash_table_insert(GLOBALS->h_cur, new_key, item);
 
 	da_cur_initformat(item);
-	
+
 	return TRUE;
 }
 
@@ -199,7 +201,7 @@ da_cur_append(Currency *item)
 Currency *existitem;
 guint32 *new_key;
 
-	DB( g_print("da_cur_append\n") );
+	DB( g_print("\n[da_cur] append\n") );
 
 	/* ensure no duplicate */
 	existitem = da_cur_get_by_name( item->name );
@@ -210,16 +212,16 @@ guint32 *new_key;
 		item->key = *new_key;
 		//item->pos = da_cur_length() + 1;
 
-		DB( g_print(" -> insert id: %d\n", *new_key) );
+		DB( g_print(" insert id: %d\n", *new_key) );
 
-		g_hash_table_insert(GLOBALS->h_cur, new_key, item);	
+		g_hash_table_insert(GLOBALS->h_cur, new_key, item);
 
 		da_cur_initformat(item);
 
 		return TRUE;
 	}
 
-	DB( g_print(" -> %s already exist: %d\n", item->iso_code, item->key) );
+	DB( g_print(" %s already exist: %d\n", item->iso_code, item->key) );
 
 	return FALSE;
 }
@@ -238,7 +240,7 @@ guint32 max_key = 0;
 Currency *
 da_cur_get_by_name(gchar *name)
 {
-	DB( g_print("da_cur_get_by_name\n") );
+	DB( g_print("\n[da_cur] get_by_name\n") );
 
 	return g_hash_table_find(GLOBALS->h_cur, (GHRFunc)da_cur_name_grfunc, name);
 }
@@ -247,7 +249,7 @@ da_cur_get_by_name(gchar *name)
 Currency *
 da_cur_get_by_iso_code(gchar *iso_code)
 {
-	DB( g_print("da_cur_get_by_iso_code\n") );
+	DB( g_print("\n[da_cur] get_by_iso_code\n") );
 
 	return g_hash_table_find(GLOBALS->h_cur, (GHRFunc)da_cur_iso_grfunc, iso_code);
 }
@@ -255,15 +257,13 @@ da_cur_get_by_iso_code(gchar *iso_code)
 Currency *
 da_cur_get(guint32 key)
 {
-	//DB( g_print("da_cur_get\n") );
+	//only use when needed
+	//DB( g_print("\n[da_cur] get\n") );
 
 	return g_hash_table_lookup(GLOBALS->h_cur, &key);
 }
 
 
-
-
-
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
@@ -285,9 +285,9 @@ gboolean retval = FALSE;
 
 /**
  * currency_is_used:
- * 
+ *
  * controls if a currency is used [base or account]
- * 
+ *
  * Return value: TRUE if used, FALSE, otherwise
  */
 gboolean
@@ -296,21 +296,23 @@ currency_is_used(guint32 key)
 GList *list;
 gboolean retval;
 
+	DB( g_printf("\n[currency] is used\n") );
+
 	if(GLOBALS->kcur == key)
 		return TRUE;
-	
+
 	retval = FALSE;
-	
+
 	list = g_hash_table_get_values(GLOBALS->h_acc);
 	while (list != NULL)
 	{
 	Account *item = list->data;
 
 		if(item->kcur == key)
-		{	
+		{
 			retval = TRUE;
 			goto end;
-		}		
+		}
 		list = g_list_next(list);
 	}
 
@@ -327,6 +329,9 @@ Currency4217 *iso4217format_get(gchar *code)
 Currency4217 *cur;
 guint i;
 
+	DB( g_printf("\n[currency] iso4217 format get\n") );
+
+
 	for (i = 0; i< n_iso4217cur; i++)
 	{
 		cur = &iso4217cur[i];
@@ -339,58 +344,133 @@ guint i;
 }
 
 
-static void currency_get_system_format(Currency *item)
+//https://msdn.microsoft.com/en-us/library/windows/desktop/dd464799%28v=vs.85%29.aspx
+//https://github.com/Samsung/icu/blob/master/source/i18n/winnmfmt.cpp
+#ifdef G_OS_WIN32
+
+#define NEW_ARRAY(type,count) (type *) g_malloc((count) * sizeof(type))
+#define DELETE_ARRAY(array) g_free((void *) (array))
+
+
+static void win_getCurrencyFormat(CURRENCYFMTW *fmt, const wchar_t *windowsLocaleName)
 {
-	DB( g_printf("\n[(currency] get format from system '%s'\n", item->iso_code) );
+//wchar_t buf[10];
+
+	DB( g_printf("\n[currency] win get system format\n") );
+
+	GetLocaleInfoEx(windowsLocaleName, LOCALE_RETURN_NUMBER|LOCALE_ICURRDIGITS, (LPWSTR) &fmt->NumDigits, sizeof(UINT));
+	//GetLocaleInfoEx(windowsLocaleName, LOCALE_RETURN_NUMBER|LOCALE_ILZERO, (LPWSTR) &fmt->LeadingZero, sizeof(UINT));
+
+	//GetLocaleInfoEx(windowsLocaleName, LOCALE_SMONGROUPING, (LPWSTR)buf, sizeof(buf));
+	//fmt->Grouping = getGrouping(buf);
+
+	fmt->lpDecimalSep = NEW_ARRAY(wchar_t, 6);
+	GetLocaleInfoEx(windowsLocaleName, LOCALE_SMONDECIMALSEP,  fmt->lpDecimalSep,  6);
+
+	fmt->lpThousandSep = NEW_ARRAY(wchar_t, 6);
+	GetLocaleInfoEx(windowsLocaleName, LOCALE_SMONTHOUSANDSEP, fmt->lpThousandSep, 6);
+
+	//GetLocaleInfoEx(windowsLocaleName, LOCALE_RETURN_NUMBER|LOCALE_INEGCURR,  (LPWSTR) &fmt->NegativeOrder, sizeof(UINT));
+	GetLocaleInfoEx(windowsLocaleName, LOCALE_RETURN_NUMBER|LOCALE_ICURRENCY, (LPWSTR) &fmt->PositiveOrder, sizeof(UINT));
+
+	fmt->lpCurrencySymbol = NEW_ARRAY(wchar_t, 8);
+	GetLocaleInfoEx(windowsLocaleName, LOCALE_SCURRENCY, (LPWSTR) fmt->lpCurrencySymbol, 8);
+}
+
+
+static void win_freeCurrencyFormat(CURRENCYFMTW *fmt)
+{
+	DB( g_printf("\n[currency] win free system format\n") );
+
+	if (fmt != NULL) {
+		DELETE_ARRAY(fmt->lpCurrencySymbol);
+		DELETE_ARRAY(fmt->lpThousandSep);
+		DELETE_ARRAY(fmt->lpDecimalSep);
+	}
+}
+
+
+static void win_currency_get_system_iso(void)
+{
+LPWSTR lpIntlSymbol;
+
+	DB( g_printf("\n[currency] get system ISO\n") );
+
+	lpIntlSymbol = NEW_ARRAY(wchar_t, 9);
+	GetLocaleInfoEx(LOCALE_NAME_USER_DEFAULT, LOCALE_SINTLSYMBOL,  lpIntlSymbol,  9);
+
+	DB( wprintf(L"raw lpIntlSymbol: '%hs'\n", lpIntlSymbol) );
+
+	gchar *tmpstr = g_utf16_to_utf8(lpIntlSymbol, -1, NULL, NULL, NULL);
+	g_stpcpy (PREFS->IntCurrSymbol, tmpstr);
+	g_free(tmpstr);
+
+	DELETE_ARRAY(lpIntlSymbol);
+}
+
+
+static void win_currency_format_system_fill(Currency *item)
+{
+CURRENCYFMTW currency;
+
+	DB( g_printf("\n[currency] windows format system fill '%s'\n", item->iso_code) );
+
+	win_getCurrencyFormat(&currency, LOCALE_NAME_USER_DEFAULT);
+
+	#if MYDEBUG == 1
+	  printf("raw ptr = %p\n", &currency);
+	  printf("raw NumDigits: '%d'\n", currency.NumDigits);
+	//note this will not print well on windows console which is not unicode compliant
+	wprintf(L"raw lpDecimalSep: '%hs'\n", currency.lpDecimalSep);
+	wprintf(L"raw lpThousandSep: '%hs'\n", currency.lpThousandSep);
+	wprintf(L"raw lpCurrencySymbol: '%hs'\n", currency.lpCurrencySymbol);
+	#endif
+
+	item->symbol        = g_utf16_to_utf8(currency.lpCurrencySymbol, -1, NULL, NULL, NULL);
+	item->sym_prefix    = (currency.PositiveOrder & 1) ? FALSE : TRUE;
+	item->decimal_char  = g_utf16_to_utf8(currency.lpDecimalSep, -1, NULL, NULL, NULL);
+	item->grouping_char = g_utf16_to_utf8(currency.lpThousandSep, -1, NULL, NULL, NULL);
+	item->frac_digits   = currency.NumDigits;
+
+	win_freeCurrencyFormat(&currency);
+}
+
+#endif
 
 
 #ifdef G_OS_UNIX
 
+
+static void unix_currency_get_system_iso(void)
+{
 struct lconv *lc = localeconv();
 
-	DB( g_print("int_curr_symbol '%s'\n", lc->int_curr_symbol) );
-	
-	DB( g_print("mon_decimal_point is utf8: %d\n", g_utf8_validate(lc->mon_decimal_point, -1, NULL)) );
-	DB( g_print("mon_decimal_point '%s'\n", lc->mon_decimal_point) );
-	DB( g_print("mon_decimal_point %x %x %x %x\n", lc->mon_decimal_point[0], lc->mon_decimal_point[1], lc->mon_decimal_point[2], lc->mon_decimal_point[3]) );
+	DB( g_printf("\n[currency] get system ISO\n") );
 
-	DB( g_print("mon_thousands_sep is utf8: %d\n", g_utf8_validate(lc->mon_thousands_sep, -1, NULL)) );
-	DB( g_print("mon_thousands_sep '%s'\n", lc->mon_thousands_sep) );
-	DB( g_print("mon_thousands_sep %x %x %x %x\n", lc->mon_thousands_sep[0], lc->mon_thousands_sep[1], lc->mon_thousands_sep[2], lc->mon_thousands_sep[3]) );
+	g_stpcpy (PREFS->IntCurrSymbol, lc->int_curr_symbol);
+}
 
 
-	DB( g_print("frac_digits '%d'\n", (gint)lc->frac_digits) );
+static void unix_currency_format_system_fill(Currency *item)
+{
+struct lconv *lc = localeconv();
 
-	DB( g_print("currency_symbol '%s'\n", lc->currency_symbol) );
+	DB( g_printf("\n[currency] linux format system fill '%s'\n", item->iso_code) );
 
-	DB( g_print("p_cs_precedes '%d'\n", lc->p_cs_precedes) );
-
-	DB( g_print("n_cs_precedes '%d'\n", lc->n_cs_precedes) );
-
-	/* ok assign */
-	item->symbol = g_strdup(lc->currency_symbol);
-
-	if( lc->p_cs_precedes || lc->n_cs_precedes )
-	{
-		item->sym_prefix  = TRUE;
-		DB( g_print("locale mon cs is a prefix\n") );
-	}
-	else
-	{
-		item->sym_prefix  = FALSE;
-	}
-
-	item->decimal_char = g_strdup(lc->mon_decimal_point);
+	#if MYDEBUG == 1
+	g_print("raw ptr = %p\n", lc);
+	g_print("raw   int_curr_symbol = '%s'\n", lc->int_curr_symbol);
+	g_print("raw     ?_cs_precedes = '%d' '%d'\n", lc->p_cs_precedes, lc->n_cs_precedes);
+	g_print("raw mon_decimal_point = '%s'\n", lc->mon_decimal_point);
+	g_print("raw mon_thousands_sep = '%s'\n", lc->mon_thousands_sep);
+	g_print("raw       frac_digits = '%d'\n", lc->frac_digits);
+	#endif
 
+	item->symbol        = g_strdup(lc->currency_symbol);
+	item->sym_prefix    = ( lc->p_cs_precedes || lc->n_cs_precedes ) ? TRUE : FALSE;
+	item->decimal_char  = g_strdup(lc->mon_decimal_point);
 	item->grouping_char = g_strdup(lc->mon_thousands_sep);
-
-	//todo:fix
-	//PREFS->base_cur.grouping_char = g_locale_to_utf8(lc->mon_thousands_sep, -1, NULL, NULL, NULL);
-	//PREFS->base_cur.grouping_char = g_convert (lc->mon_thousands_sep, -1, "UTF-8", "ISO-8859-1", NULL, NULL, NULL);
-
-	DB( g_print(" -> grouping_char: '%s'\n", item->grouping_char) );
-
-	item->frac_digits = lc->frac_digits;
+	item->frac_digits   = lc->frac_digits;
 
 	//fix 378992/421228
 	if( item->frac_digits > MAX_FRAC_DIGIT )
@@ -399,69 +479,39 @@ struct lconv *lc = localeconv();
 		g_free(item->decimal_char);
 		item->decimal_char = g_strdup(".");
 	}
-
-#else
-	#ifdef G_OS_WIN32
-    #define BUFFER_SIZE 512
-    char buffer[BUFFER_SIZE];
-    //LPWSTR wcBuffer = buffer;
-    LPSTR wcBuffer = buffer;
-    int iResult;
-
-	//https://msdn.microsoft.com/en-us/library/windows/desktop/dd464799%28v=vs.85%29.aspx
-
-    //see g_locale_to_utf8 here
-	iResult = GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_SCURRENCY, wcBuffer, BUFFER_SIZE);
-    if(iResult > 0)
-    {
-        DB( g_print("LOCALE_SCURRENCY='%s'\n", buffer) );
-        item->symbol = g_locale_to_utf8(buffer, -1, NULL, NULL, NULL);
-    }
-
-	item->sym_prefix = FALSE;
-	iResult = GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_IPOSSYMPRECEDES, wcBuffer, BUFFER_SIZE);
-    if(iResult > 0)
-    {
-        DB( g_print("LOCALE_IPOSSYMPRECEDES='%s'\n", buffer) );
-		//todo item->sym_prefix
-        
-    }
-
-	iResult = GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_SDECIMAL, wcBuffer, BUFFER_SIZE);
-    if(iResult > 0)
-    {
-        DB( g_print("LOCALE_SDECIMAL='%s'\n", buffer) );
-        item->decimal_char = g_locale_to_utf8(buffer, -1, NULL, NULL, NULL);
-    }
-
-	iResult = GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_STHOUSAND, wcBuffer, BUFFER_SIZE);
-    if(iResult > 0)
-    {
-        DB( g_print("LOCALE_STHOUSAND='%s'\n", buffer) );
-        item->grouping_char = g_locale_to_utf8(buffer, -1, NULL, NULL, NULL);
-    }
-
-	iResult = GetLocaleInfoA(LOCALE_USER_DEFAULT, LOCALE_ICURRDIGITS, wcBuffer, BUFFER_SIZE);
-    if(iResult > 0)
-    {
-        DB( g_print("LOCALE_ICURRDIGITS='%s'\n", buffer) );
-        item->frac_digits = atoi(buffer);
-    }
-	else
-	 	item->frac_digits = 2;
-
-	#endif
+}
 #endif
 
 
+void currency_get_system_iso(void)
+{
+	DB( g_print("\n[currency] get system ISO code\n") );
+
+#ifdef G_OS_UNIX
+	unix_currency_get_system_iso();
+#else
+	#ifdef G_OS_WIN32
+	win_currency_get_system_iso();
+	#else
+ 	g_stpcpy (PREFS->IntCurrSymbol, "USD");
+	#endif
+#endif
+
+	g_strstrip(PREFS->IntCurrSymbol);
+
+	DB( g_print("- stored '%s' as default\n", PREFS->IntCurrSymbol) );
+
 }
 
 
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
+
+
 Currency *currency_add_from_user(Currency4217 *curfmt)
 {
 Currency *item;
-	
-	DB( g_printf("\n[(currency] found adding %s\n", curfmt->curr_iso_code) );
+
+	DB( g_printf("\n[currency] found adding %s\n", curfmt->curr_iso_code) );
 
 	item = da_cur_malloc();
 	//no mem alloc here
@@ -471,33 +521,55 @@ Currency *item;
 		item->name = g_strdup(curfmt->name);
 		//item->country = cur.country_name;
 		item->iso_code = g_strdup(curfmt->curr_iso_code);
-		
+
 		//1634615 if the currency match the system, fill with it
 		if(!strcmp(item->iso_code, PREFS->IntCurrSymbol))
 		{
-			currency_get_system_format(item);
+			#ifdef G_OS_UNIX
+			unix_currency_format_system_fill(item);
+			#else
+				#ifdef G_OS_WIN32
+				win_currency_format_system_fill(item);
+				#endif
+			#endif
 		}
 		else
 		{
-			item->frac_digits = curfmt->curr_frac_digit;
-			item->symbol = g_strdup(curfmt->curr_symbol);
-			item->sym_prefix = curfmt->curr_is_prefix;
-			item->decimal_char = g_strdup(curfmt->curr_dec_char);
+			//init from our internal iso 4217 preset
+			item->frac_digits   = curfmt->curr_frac_digit;
+			item->symbol        = g_strdup(curfmt->curr_symbol);
+			item->sym_prefix    = curfmt->curr_is_prefix;
+			item->decimal_char  = g_strdup(curfmt->curr_dec_char);
 			item->grouping_char = g_strdup(curfmt->curr_grp_char);
 		}
 	}
 	else
 	{
-		item->name = g_strdup("unknown");
-		//item->country = cur.country_name;
-		item->iso_code = g_strdup("XXX");
+		item->name        = g_strdup("unknown");
+		//item->country     = cur.country_name;
+		item->iso_code    = g_strdup("XXX");
 		item->frac_digits = 2;
-		item->symbol = g_strdup("XXX");
-		item->sym_prefix = FALSE;
-		item->decimal_char = g_strdup(".");
-		item->grouping_char = NULL;
+		item->sym_prefix  = FALSE;
 	}
-		
+
+	//#1862540 if symbol/decimal/grouping char are null = crash on hb_str_formatd()
+	if( !item->symbol )
+		item->symbol = g_strdup("XXX");
+
+	if( !item->decimal_char )
+		item->decimal_char = g_strdup(".");
+
+	if( !item->grouping_char )
+		item->grouping_char = g_strdup("");
+
+	#if MEDEBUG == 1
+	g_printf("        symbol ='%s'\n", item->symbol);
+	g_printf("    sym_prefix ='%d'\n", item->sym_prefix);
+	g_printf("  decimal_char ='%s'\n", item->decimal_char);
+	g_printf(" grouping_char ='%s'\n", item->grouping_char);
+	g_printf("   frac_digits ='%d'\n", item->frac_digits);
+	#endif
+
 	da_cur_append(item);
 
 	return item;
@@ -509,6 +581,8 @@ static gboolean currency_rate_update(gchar *isocode, gdouble rate, guint32 date)
 gboolean retval = FALSE;
 Currency *cur;
 
+	DB( g_print("\n[currency] rate update\n") );
+
 	cur = da_cur_get_by_iso_code (isocode);
 	if(cur)
 	{
@@ -536,9 +610,9 @@ Currency *cur;
 /* old
 ** api.fixer.io deprecated since 30/04/2019
 ** QS: https://api.fixer.io/latest?base=EUR&symbols=USD,CHF,AUD,CAD,JPY,CNY,GBP
-** 
+**
 ** test API
-** gchar fixeriojson[] = 
+** gchar fixeriojson[] =
 ** "{    }";
 ** "	{	\r	\"base\"	:	\"EUR\", \
 ** \"date\":	\n\r		\"2017-12-04\", \
@@ -557,6 +631,8 @@ gdouble rate;
 guint32 date = GLOBALS->today;
 guint count = 0;
 
+	DB( g_print("\n[currency] api fixerio parse\n") );
+
 	if(body)
 	{
 		//there is no need of a complex JSON parser here, so let's hack !
@@ -590,7 +666,7 @@ guint count = 0;
 
 				if( currency_rate_update(isocode, rate, date) )
 					count++;
-			}			
+			}
 			while( p != NULL );
 		}
 
@@ -610,6 +686,8 @@ Currency *base;
 Currency *item;
 gint i;
 
+	DB( g_print("\n[currency] api fixerio query build\n") );
+
 	base = da_cur_get (GLOBALS->kcur);
 
 	node = g_string_sized_new(512);
@@ -656,7 +734,7 @@ gboolean retval = TRUE;
 	query = api_fixerio_query_build();
 	DB( g_printf("query: '%s'\n", query) );
 
-	/* 
+	/*
 	//test API
 	retval = api_fixerio_parse(fixeriojson, error);
 	*/
@@ -670,7 +748,7 @@ gboolean retval = TRUE;
 		DB( g_print("status_code: %d %d\n", msg->status_code, SOUP_STATUS_IS_SUCCESSFUL(msg->status_code) ) );
 		DB( g_print("reason: %s\n", msg->reason_phrase) );
 		DB( g_print("datas: %s\n", msg->response_body->data) );
-		
+
 		if( SOUP_STATUS_IS_SUCCESSFUL(msg->status_code) == TRUE )
 		{
 			//#1750426 ignore the retval here (false when no rate was found, as we don't care)
@@ -691,11 +769,11 @@ gboolean retval = TRUE;
 	}
 
 	g_free(query);
-	
+
 	soup_session_abort (session);
 
 	g_object_unref(session);
-	
+
 	return retval;
 }
 
@@ -711,14 +789,14 @@ static void fill_currency(void)
 gint i;
 struct iso_4217_currency cur;
 Currency *item;
-	
+
 	for (i = 0; i< 500; i++)
 	{
 		cur = iso_4217_currencies[i];
 
 		if(cur.iso_code == NULL)
 			break;
-		
+
 		item = da_cur_malloc();
 		//no mem alloc here
 		item->key = i;
@@ -730,7 +808,7 @@ Currency *item;
 
 	}
 
-	
+
 
 }*/
 
