@@ -567,7 +567,7 @@ gint i, col;
 		}
 		
 		i = 4;
-		hb_strfnum(amtbuf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->amount, txn->kcur, GLOBALS->minor);
+		hb_strfmon(amtbuf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->amount, txn->kcur, GLOBALS->minor);
 		pango_layout_set_text (layout, amtbuf, -1);
 		pango_layout_get_size (layout, &tw, &th);
 		ppc.column_width[i] = MAX(ppc.column_width[i], tw / PANGO_SCALE);
@@ -578,7 +578,7 @@ gint i, col;
 		ppc.column_width[i] = MAX(ppc.column_width[i], tw / PANGO_SCALE);
 
 		i = 6;
-		hb_strfnum(balbuf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->balance, txn->kcur, GLOBALS->minor);
+		hb_strfmon(balbuf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->balance, txn->kcur, GLOBALS->minor);
 		pango_layout_set_text (layout, balbuf, -1);
 		pango_layout_get_size (layout, &tw, &th);
 		ppc.column_width[i] = MAX(ppc.column_width[i], tw / PANGO_SCALE);
@@ -693,14 +693,14 @@ gint i, col;
 		ppc.column_txt[i] = txn->memo;
 			
 		i = 4;
-		hb_strfnum(amtbuf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->amount, txn->kcur, GLOBALS->minor);
+		hb_strfmon(amtbuf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->amount, txn->kcur, GLOBALS->minor);
 		ppc.column_txt[i] = amtbuf;
 
 		i = 5;
 		ppc.column_txt[i] = transaction_get_status_string(txn);
 		
 		i = 6;
-		hb_strfnum(balbuf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->balance, txn->kcur, GLOBALS->minor);
+		hb_strfmon(balbuf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->balance, txn->kcur, GLOBALS->minor);
 		ppc.column_txt[i] = balbuf;
 
 		hb_pdf_draw_line(&ppc, cr, y, FALSE, (cur_page_line % 2));
