@@ -182,8 +182,13 @@ gint i;
 	}
 
 	flt->option[FILTER_DATE] = 1;
-	flt->range  = FLT_RANGE_LAST12MONTHS;
-	filter_preset_daterange_set(flt, flt->range, 0);
+
+	//5.4.2: useless, as it is always changed after all
+	//flt->range  = FLT_RANGE_LAST12MONTHS;
+	//filter_preset_daterange_set(flt, flt->range, 0);
+	flt->range = FLT_RANGE_LAST30DAYS;
+	flt->mindate = GLOBALS->today-30;
+	flt->maxdate = GLOBALS->today;
 
 	for(i=0;i<NUM_PAYMODE_MAX;i++)
 		flt->paymode[i] = TRUE;
@@ -549,6 +554,9 @@ gchar *retval = NULL;
 }
 
 
+/* = = = = = = = = = = = = = = = = */
+
+
 /* used for quicksearch text into transaction */
 gboolean filter_tpl_search_match(gchar *needle, Archive *arc)
 {
