@@ -1167,9 +1167,6 @@ gint nsplit;
 		newope->memo		 = g_strdup(gentxn->memo);
 		newope->amount		 = gentxn->amount;
 
-		if(newope->amount > 0)
-			newope->flags |= OF_INCOME;
-
 		//#773282 invert amount for ccard accounts
 		//todo: manage this (qif), it is not set to true anywhere
 		//= it is into the qif account see hb-import-qif.c
@@ -1285,8 +1282,8 @@ gint nsplit;
 		}
 		
 		newope->flags |= OF_ADDED;
-		if( newope->amount > 0 )
-			newope->flags |= OF_INCOME;
+		
+		da_transaction_set_flag(newope);
 
 		if( gentxn->reconciled )
 			newope->status = TXN_STATUS_RECONCILED;
