@@ -658,14 +658,28 @@ gchar gdc='.';
 gchar *hb_string_dup_raw_amount_clean(const gchar *string, gint digits)
 {
 gint l;
-gchar *new_str, *d;
+gchar *san_str, *new_str, *d;
 gchar gdc;
-const gchar *p = string;
+const gchar *p;
 
-	l = strlen(string);
-	gdc = hb_string_raw_amount_guess_dchar(string, l, digits);
+	//sanitize the string first: keep -,.0-9
+	//#1876134 windows: pasted numbers from calculator loose dchar
+	//https://github.com/microsoft/calculator/issues/504
+	san_str = d = g_strdup(string);
+	p = string;
+	while(*p)
+	{
+		if( g_ascii_isdigit(*p) || *p=='-' || *p=='.' || *p==',' )
+			*d++ = *p;
+		p++;
+	}
+	*d++ = '\0';
+
+	l = strlen(san_str);
+	gdc = hb_string_raw_amount_guess_dchar(san_str, l, digits);
 
 	new_str = d = g_malloc (l+1);
+	p = san_str;
 	while(*p)
 	{
 		if(*p=='-' || g_ascii_isdigit(*p) )
@@ -679,6 +693,8 @@ const gchar *p = string;
 	}
 	*d++ = '\0';
 
+	g_free(san_str);
+
 	return new_str;	
 }
 
