@@ -166,11 +166,15 @@ gint i;
 	PREFS->txn_memoacp_days = 365;
 
 	PREFS->toolbar_style = 4;	//text beside icons
+	PREFS->grid_lines = GTK_TREE_VIEW_GRID_LINES_NONE;
+	
+	PREFS->gtk_override = FALSE;
+	PREFS->gtk_fontsize = 10;
+
 	PREFS->custom_colors = TRUE;
 	PREFS->color_exp  = g_strdup(DEFAULT_EXP_COLOR);
 	PREFS->color_inc  = g_strdup(DEFAULT_INC_COLOR);
 	PREFS->color_warn = g_strdup(DEFAULT_WARN_COLOR);
-	PREFS->grid_lines = GTK_TREE_VIEW_GRID_LINES_NONE;
 
 	/* fiscal year */
 	PREFS->fisc_year_day = 1;
@@ -439,6 +443,38 @@ static void homebank_pref_currfmt_convert(Currency *cur, gchar *prefix, gchar *s
 }
 
 
+void homebank_pref_apply(void)
+{
+GtkSettings *settings = gtk_settings_get_default();
+
+	DB( g_print("\n[preferences] pref apply\n") );
+
+	if( PREFS->gtk_override == TRUE )
+	{
+	PangoFontDescription *pfd;
+	gchar *oldfn, *newfn;
+
+		g_object_get(settings, "gtk-font-name", &oldfn, NULL);
+		pfd = pango_font_description_from_string(oldfn);
+		DB( g_print(" font-name '%s' == '%s' %d\n", oldfn, pango_font_description_get_family(pfd), pango_font_description_get_size(pfd)/PANGO_SCALE) );
+		g_free(oldfn);
+
+		pango_font_description_set_size(pfd, PREFS->gtk_fontsize*PANGO_SCALE);
+
+		newfn = pango_font_description_to_string(pfd);
+		DB( g_print(" font-name '%s' == '%s' %d\n", newfn, pango_font_description_get_family(fd), pango_font_description_get_size(fd)/PANGO_SCALE) );
+		g_object_set(settings, "gtk-font-name", newfn, NULL);
+		g_free(newfn);
+
+		pango_font_description_free(pfd);
+	}
+	else
+	{
+		gtk_settings_reset_property(settings, "gtk-font-name");
+	}
+}
+
+
 gboolean homebank_pref_load(void)
 {
 GKeyFile *keyfile;
@@ -491,6 +527,10 @@ GError *error = NULL;
 					PREFS->toolbar_style = 4;
 				}
 
+				//5.4.3
+				homebank_pref_get_boolean(keyfile, group, "GtkOverride", &PREFS->gtk_override);
+				homebank_pref_get_short(keyfile, group, "GtkFontSize" , &PREFS->gtk_fontsize);
+
 				if(version <= 2)	// retrieve old settings
 				{
 				guint32 color;
@@ -823,6 +863,7 @@ GError *error = NULL;
 				homebank_pref_get_boolean(keyfile, group, "DoIntro", &PREFS->dtex_nointro);
 				homebank_pref_get_boolean(keyfile, group, "UcFirst", &PREFS->dtex_ucfirst);
 				homebank_pref_get_integer(keyfile, group, "DateFmt", &PREFS->dtex_datefmt);
+				homebank_pref_get_integer(keyfile, group, "DayGap", &PREFS->dtex_daygap);
 				homebank_pref_get_integer(keyfile, group, "OfxName", &PREFS->dtex_ofxname);
 				homebank_pref_get_integer(keyfile, group, "OfxMemo", &PREFS->dtex_ofxmemo);
 				homebank_pref_get_boolean(keyfile, group, "QifMemo", &PREFS->dtex_qifmemo);
@@ -900,6 +941,8 @@ GError *error = NULL;
 		g_key_file_set_integer (keyfile, group, "BarStyle", PREFS->toolbar_style);
 		//g_key_file_set_integer (keyfile, group, "BarImageSize", PREFS->image_size);
 
+		g_key_file_set_boolean (keyfile, group, "GtkOverride", PREFS->gtk_override);
+		g_key_file_set_integer (keyfile, group, "GtkFontSize", PREFS->gtk_fontsize);
 
 
 		g_key_file_set_boolean (keyfile, group, "CustomColors", PREFS->custom_colors);
@@ -1027,6 +1070,7 @@ GError *error = NULL;
 		g_key_file_set_boolean (keyfile, group, "DoIntro", PREFS->dtex_nointro);
 		g_key_file_set_boolean (keyfile, group, "UcFirst", PREFS->dtex_ucfirst);
 		g_key_file_set_integer (keyfile, group, "DateFmt", PREFS->dtex_datefmt);
+		g_key_file_set_integer (keyfile, group, "DayGap", PREFS->dtex_daygap);
 		g_key_file_set_integer (keyfile, group, "OfxName", PREFS->dtex_ofxname);
 		g_key_file_set_integer (keyfile, group, "OfxMemo", PREFS->dtex_ofxmemo);
 		g_key_file_set_boolean (keyfile, group, "QifMemo", PREFS->dtex_qifmemo);
