@@ -74,9 +74,11 @@ struct Preferences
 
 	//interface
 	gshort		toolbar_style;
+	gshort		grid_lines;
+	gboolean	gtk_override;
+	gshort		gtk_fontsize;
 
 	gboolean	icon_symbolic;
-	gshort		grid_lines;
 	gboolean	custom_colors;
 	gchar		*color_exp;
 	gchar		*color_inc;
@@ -104,6 +106,7 @@ struct Preferences
 
 	//import/export
 	gint		dtex_datefmt;
+	gint		dtex_daygap;
 	gint		dtex_ofxname;
 	gint		dtex_ofxmemo;
 	gboolean	dtex_qifmemo;
@@ -190,6 +193,8 @@ void homebank_prefs_set_default(void);
 void homebank_pref_free(void);
 void homebank_pref_createformat(void);
 void homebank_pref_init_measurement_units(void);
+
+void homebank_pref_apply(void);
 gboolean homebank_pref_load(void);
 gboolean homebank_pref_save(void);
 void homebank_pref_setdefault(void);
