@@ -411,6 +411,15 @@ gboolean found;
 }
 
 
+void da_transaction_set_flag(Transaction *item)
+{
+	//DB( g_print("\n[transaction] set flag\n") );
+	item->flags &= ~(OF_INCOME);
+	if( item->amount > 0)
+		item->flags |= (OF_INCOME);
+}
+
+
 void da_transaction_consistency(Transaction *item)
 {
 Account *acc;
@@ -486,7 +495,7 @@ guint nbsplit;
 			item->kxferacc = 0;
 		}
 	}
-		
+
 	// intxfer: check dst account exists
 	if( (item->flags & OF_INTXFER) || (item->paymode == OLDPAYMODE_INTXFER) )
 	{
@@ -508,9 +517,7 @@ guint nbsplit;
 	//#1787826 intxfer should not have split
 
 	//#1295877 ensure income flag is correctly set
-	item->flags &= ~(OF_INCOME);
-	if( item->amount > 0)
-		item->flags |= (OF_INCOME);
+	da_transaction_set_flag(item);
 
 	//#1308745 ensure remind flag unset if reconciled
 	//useless since 5.0
