@@ -570,7 +570,9 @@ gint i;
 	}
 
 	//all attribute loaded: append
-	da_asg_append(entry);
+	//#1892828 append change the pos...
+	//da_asg_append(entry);
+	da_asg_insert(entry);
 
 }
 
@@ -973,7 +975,8 @@ gchar *v_buffer;
 	v_buffer = g_strstr_len(buffer+13, 50, "d=");
 	if( v_buffer )
 	{
-		DB( g_print(" d=%s)\n\n", v_buffer) );
+		//TODO: beware here of we display all the file...
+		DB( g_print(" d=%.25s)\n\n", v_buffer) );
 	
 		ctx->data_version = atoi(v_buffer+3);
 	}
@@ -1126,7 +1129,6 @@ gboolean rc, dosanity;
 			//fix payee defaut payment to int xfer from 5.1
 			dosanity = TRUE;
 		}
-
 		if( ctx.file_version < 1.4 )	// <= 5.3 
 		{
 			homebank_upgrade_to_v14();
@@ -1134,8 +1136,8 @@ gboolean rc, dosanity;
 		}
 		// next ?
 
-		
-		// always run sanity check after upgrade
+
+		// sanity check at last
 		if( dosanity == TRUE )
 			hbfile_sanity_check();
 
@@ -1799,6 +1801,7 @@ gint retval = XML_OK;
 GError *error = NULL;
 
 	io = g_io_channel_new_file(filename, "w", &error);
+	//The default encoding for the external file is UTF-8.
 	if(error)
 	{
 		g_warning("unable to save file %s: %s", filename, error->message);
