@@ -441,6 +441,7 @@ homebank_theme_changed (GtkSettings *settings, GParamSpec  *pspec, gpointer
 	}
 }
 
+
 static void
 homebank_setup_theme_extensions (void)
 {
@@ -732,8 +733,11 @@ static gboolean homebank_setup()
 	homebank_check_app_dir();
 
 	homebank_pref_setdefault();
+
 	homebank_pref_load();
 
+	homebank_pref_apply();
+	
 	hbfile_setup(TRUE);
 
 	homebank_icon_theme_setup();
@@ -856,7 +860,6 @@ GOptionGroup *option_group;
 GError *error = NULL;
 GtkWidget *mainwin;
 GtkWidget *splash = NULL;
-gboolean openlast;
 
 	DB( g_print("\n--------------------------------" ) );
 	DB( g_print("\nhomebank starting...\n" ) );
@@ -941,109 +944,50 @@ gboolean openlast;
 
 		if(mainwin)
 		{
-
+		gchar *rawfilepath;
+		
 			//todo: pause on splash
 			if( PREFS->showsplash == TRUE )
 			{
 				//g_usleep( G_USEC_PER_SEC * 1 );
 				gtk_widget_hide(splash);
 				gtk_widget_destroy(splash);
+
+				/* make sure splash is gone */
+				while (gtk_events_pending ())
+					gtk_main_iteration ();
 			}
 
-
-#if HB_UNSTABLE == TRUE
-/*			GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW(mainwin),
-                      GTK_DIALOG_DESTROY_WITH_PARENT,
-                      GTK_MESSAGE_WARNING,
-                      GTK_BUTTONS_CLOSE,
-                      "This is a beta version of HomeBank (UNSTABLE)"
-                      );
-
-			gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog),
-						"DO NOT USE with important files or do a backup first.\n"
-						"This kind of release is for <b>TESTING ONLY</b>.\n"
-						"<u>It may be buggy, crash, or lose your data</u>.\n\n"
-
-						"For unstable bugs report, questions, suggestions:\n"
-			            " - <b>DO NOT USE LaunchPad</b>\n"
-			            " - direct email to: &lt;homebank@free.fr&gt;\n\n"
-
-			            "<i>Thanks !</i>"
-			            );
-
-			gtk_dialog_run (GTK_DIALOG (dialog));
-			gtk_widget_destroy (dialog);*/
-#endif
-
-			if(GLOBALS->first_run)
+			rawfilepath = NULL;
+			//priority here:
+			// - command line file
+			// - welcome dialog 
+			// - last opened file, if welcome dialog was not opened
+			if( files != NULL )
+			{
+				DB( g_print(" command line open '%s'\n", files[0] ) );
+				rawfilepath = g_strdup(files[0]);
+				g_strfreev (files);
+			}
+			else
+			if( PREFS->showwelcome )
 			{
 				ui_mainwindow_action_help_welcome();
 			}
-
-
-			while (gtk_events_pending ()) /* make sure splash is gone */
-				gtk_main_iteration ();
-
-
-			DB( g_print(" - open last file ?\n" ) );
-
-			// load a file ?
-			/* load 1st file specified on commandline */
-			openlast = PREFS->loadlast;
-			if (files != NULL)
+			else
+			if( PREFS->loadlast )
 			{
-				if (g_file_test (files[0], G_FILE_TEST_EXISTS) != FALSE)
-				{
-					DB( g_print(" - should load %s\n", files[0] ) );
-					hbfile_change_filepath(g_strdup(files[0]));
-					ui_mainwindow_open_internal(mainwin, NULL);
-					openlast = FALSE;
-				}
-				else
-				{
-					g_warning (_("Unable to open '%s', the file does not exist.\n"), files[0]);
-
-				}
-				g_strfreev (files);
+				rawfilepath = homebank_lastopenedfiles_load();
 			}
 
+			ui_mainwindow_open_check(mainwin, rawfilepath);
 
-			DB( g_print(" - GLOBALS->xhb_filepath: '%s'\n", GLOBALS->xhb_filepath ) );
+			/* -- hack here to generate a big file -- */
 
-			if( openlast )
-			{
-			gchar *lastfilepath;
-			
-				lastfilepath = homebank_lastopenedfiles_load();
-				if( lastfilepath != NULL )
-				{
-					//#1710955 test for backup open
-					if( hbfile_file_isbackup(lastfilepath) )
-					{
-						if( ui_mainwindow_open_backup_check_confirm(lastfilepath) == TRUE )
-						{
-							GLOBALS->hbfile_is_bak = TRUE;
-						}
-						else
-						{
-							g_free(lastfilepath);
-							goto nobak;
-						}
-					}
-
-					hbfile_change_filepath(lastfilepath);
-					ui_mainwindow_open_internal(mainwin, NULL);
-
-				}
-			}
-
-			/* -- hack to generate a big file -- */
-
-
-nobak:
 
 			/* update the mainwin display */
-			ui_mainwindow_update(mainwin, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_BALANCE+UF_VISUAL));
+			//TODO: not sure this is usefull here
+			ui_mainwindow_update(mainwin, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_VISUAL));
 
 			DB( g_print(" - gtk_main()\n" ) );
 			gtk_main ();
