@@ -28,7 +28,7 @@
 /****************************************************************************/
 /* Debug macros                                                             */
 /****************************************************************************/
-#define MYDEBUG 0
+#define MYDEBUG 1
 
 #if MYDEBUG
 #define DB(x) (x);
@@ -242,7 +242,7 @@ Account *acc;
 				if(i >= n_items)
 					other += item->value;
 
-				DB( g_print(" - %d : k='%d' v='%f' t='%f'\n", i, item->key, item->value, total) );
+				DB( g_print(" - %d : k='%d' v='%f' t='%f o='%f''\n", i, item->key, item->value, total, other) );
 
 			}
 		}
