@@ -187,15 +187,18 @@ static void list_txn_eval_future(GtkCellRenderer *renderer, Transaction *txn)
 	if(txn->date > GLOBALS->today)
 	{
 		g_object_set(renderer, 
-		//	"scale-set", TRUE, 
-			"scale", 0.8,
+		//	"scale-set", TRUE,
+		//5.4.3 scale disabled
+		//	"scale", 0.8,
 		//	"style-set", TRUE,
 			"style",	PANGO_STYLE_OBLIQUE,
 		NULL);
 	}
 	else
 	{
-		g_object_set(renderer, "scale-set", FALSE, "style-set", FALSE,
+		//5.4.3 scale disabled
+		g_object_set(renderer, "style-set", FALSE,
+		//g_object_set(renderer, "scale-set", FALSE, "style-set", FALSE,
 		NULL);
 	}
 	
@@ -596,39 +599,125 @@ gchar *color, *text;
 
 /* = = = = = = = = = = = = = = = = */
 
+
+static void list_txn_to_string_line(GString *node, gchar sep, Transaction *ope, guint32 kcat, gchar *memo, gdouble amount, gboolean incacc)
+{
+Payee *payee;
+Category *category;
+gchar *tags;
+char strbuf[G_ASCII_DTOSTR_BUF_SIZE];
+
+	//account
+	if( incacc )
+	{
+	Account *acc = da_acc_get(ope->kacc);
+	
+		g_string_append (node, (acc != NULL) ? acc->name : "");
+		g_string_append_c (node, sep );
+	}
+
+	//date
+	hb_sprint_date(strbuf, ope->date);
+	g_string_append (node, strbuf );
+	g_string_append_c (node, sep );
+	
+	//paymode
+	g_snprintf(strbuf, sizeof (strbuf), "%d", ope->paymode);
+	g_string_append (node, strbuf );
+	g_string_append_c (node, sep );
+
+	//info
+	g_string_append (node, (ope->info != NULL) ? ope->info : "" );
+	g_string_append_c (node, sep );
+		
+	//payee	
+	payee = da_pay_get(ope->kpay);
+	g_string_append (node, (payee->name != NULL) ? payee->name : "");
+	g_string_append_c (node, sep );
+
+	//memo
+	g_string_append (node, (memo != NULL) ? memo : "" );
+	g_string_append_c (node, sep );
+
+	//amount
+
+
+	//#793719
+	//g_ascii_dtostr (amountbuf, sizeof (amountbuf), ope->amount);
+	//#1750257 use locale numdigit
+	//g_ascii_formatd (amountbuf, sizeof (amountbuf), "%.2f", ope->amount);
+	//TODO: or not we should use the currency fmt here
+	g_snprintf(strbuf, sizeof (strbuf), "%.2f", amount);
+
+	DB( g_print("amount = %f '%s'\n", amount, strbuf) );
+	g_string_append (node, strbuf );
+	g_string_append_c (node, sep );
+
+	//status
+	g_string_append (node, transaction_get_status_string(ope) );
+	g_string_append_c (node, sep );
+
+
+	//category
+	category = da_cat_get(kcat);
+	g_string_append (node, (category->fullname != NULL) ? category->fullname : "" );
+	g_string_append_c (node, sep );
+
+	//tags
+	tags = tags_tostring(ope->tags);
+	g_string_append (node, tags != NULL ? tags : "");
+	g_free(tags);
+
+	//eol
+	g_string_append (node, "\n" );
+
+}
+
+
 //#1847907 v 5.3.2 add reconcile as c column like in pdf export
-GString *list_txn_to_string(GtkTreeView *treeview, gboolean clipboard)
+GString *list_txn_to_string(GtkTreeView *treeview, gboolean clipboard, gboolean incsplit, gboolean incacc)
 {
 struct list_txn_data *data = NULL;
 GtkTreeModel *model;
 GtkTreeIter	iter;
 gboolean valid;
 GString *node;
-const gchar *format;
 Transaction *ope;
-gchar datebuf[16];
-gchar *payeename, *categoryname;
 gdouble amount, samount;
-Payee *payee;
-Category *category;
-gchar *tags;
-char amountbuf[G_ASCII_DTOSTR_BUF_SIZE];
+gchar sep;
 
 	data = g_object_get_data(G_OBJECT(treeview), "inst_data");
 	
 	node = g_string_new(NULL);
 
-	if(clipboard)
+	sep = (clipboard == TRUE) ? '\t' : ';';
+
+	// header line
+	if( incacc )
 	{
-		g_string_append (node, "date\tpaymode\tinfo\tpayee\tmemo\tamount\tc\tcategory\ttags\n");
-		format = "%s\t%d\t%s\t%s\t%s\t%s\t%s\t%s\t%s\n";
+		g_string_append (node, "account" );
+		g_string_append_c (node, sep );
 	}
-	else
-	{
-		g_string_append (node, "date;paymode;info;payee;memo;amount;c;category;tags\n");
-		format = "%s;%d;%s;%s;%s;%s;%s;%s;%s\n";
-	}
-	
+	g_string_append (node, "date" );
+	g_string_append_c (node, sep );
+	g_string_append (node, "paymode" );
+	g_string_append_c (node, sep );
+	g_string_append (node, "info" );
+	g_string_append_c (node, sep );
+	g_string_append (node, "payee" );
+	g_string_append_c (node, sep );
+	g_string_append (node, "memo" );
+	g_string_append_c (node, sep );
+	g_string_append (node, "amount" );
+	g_string_append_c (node, sep );
+	g_string_append (node, "c" );
+	g_string_append_c (node, sep );
+	g_string_append (node, "category" );
+	g_string_append_c (node, sep );
+	g_string_append (node, "tags");
+	g_string_append (node, "\n" );
+
+	// each txn	
 	model = gtk_tree_view_get_model(treeview);
 	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
 	while (valid)
@@ -638,42 +727,32 @@ char amountbuf[G_ASCII_DTOSTR_BUF_SIZE];
 		    MODEL_TXN_SPLITAMT, &samount,
 			-1);
 
-		hb_sprint_date(datebuf, ope->date);
+		//normal export: if we don't want split or the txn has no split
+		if( (incsplit == FALSE) )
+		{
+			amount = ope->amount;
+			//for detail display the split part (if any)
+			if( data && (data->list_type == LIST_TXN_TYPE_DETAIL) )
+				amount = samount;
+			list_txn_to_string_line(node, sep, ope, ope->kcat, ope->memo, amount, incacc);
+		}
+		else
+		{
+			if( (ope->splits == NULL) )
+			{
+				list_txn_to_string_line(node, sep, ope, ope->kcat, ope->memo, ope->amount, incacc);
+			}
+			else
+			{
+			guint i, nbsplit = da_splits_length(ope->splits);
 
-		payee = da_pay_get(ope->kpay);
-		payeename = (payee->name == NULL) ? "" : payee->name;
-		category = da_cat_get(ope->kcat);
-		categoryname = (category->name == NULL) ? NULL : category->fullname;
-		tags = tags_tostring(ope->tags);
-
-		amount = ope->amount;
-		//for detail display the split part (if any)
-		if( data && (data->list_type == LIST_TXN_TYPE_DETAIL) )
-			amount = samount;
-
-		//#793719
-		//g_ascii_dtostr (amountbuf, sizeof (amountbuf), ope->amount);
-		//#1750257 use locale numdigit
-		//g_ascii_formatd (amountbuf, sizeof (amountbuf), "%.2f", ope->amount);
-		//TODO: we should use the currency fmt here
-		g_snprintf(amountbuf, sizeof (amountbuf), "%.2f", amount);
-
-		DB( g_print("amount = %f '%s'\n", amount, amountbuf) );
-
-		g_string_append_printf(node, format,
-				datebuf,
-				ope->paymode,
-				ope->info != NULL ? ope->info : "",
-				payeename,
-				ope->memo != NULL ? ope->memo : "",
-				amountbuf,
-		        transaction_get_status_string(ope),
-				categoryname != NULL ? categoryname : "",
-				tags != NULL ? tags : ""
-				);
-
-		//leak
-		g_free(tags);
+				for(i=0;i<nbsplit;i++)
+				{
+				Split *split = da_splits_get(ope->splits, i);
+					list_txn_to_string_line(node, sep, ope, split->kcat, split->memo, split->amount, incacc);
+				}
+			}
+		}
 
 		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
 	}
@@ -1328,10 +1407,11 @@ GtkTreeViewColumn  *column, *col_acc = NULL, *col_status = NULL;
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	col_acc = column;
 	// add column popup
-	g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 
 	/* column 2: Date */
 	column = gtk_tree_view_column_new();
@@ -1344,34 +1424,38 @@ GtkTreeViewColumn  *column, *col_acc = NULL, *col_status = NULL;
 	//gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	// add column popup
-    g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 
 	column = list_txn_column_info_create(list_type);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	// add column popup
-    g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 
 	column = list_txn_column_text_create(list_type, _("Payee"), LST_DSPOPE_PAYEE, list_txn_payee_cell_data_function, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	// add column popup
-    g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 
 	column = list_txn_column_text_create(list_type, _("Memo"), LST_DSPOPE_MEMO, list_txn_memo_cell_data_function, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	// add column popup
-    g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 
 	/* column status CLR */
 	column = gtk_tree_view_column_new();
@@ -1388,51 +1472,57 @@ GtkTreeViewColumn  *column, *col_acc = NULL, *col_status = NULL;
 	//gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	// add column popup
-    g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 	
 	
 	column = list_txn_column_amount_create(list_type, _("Amount"), LST_DSPOPE_AMOUNT, list_txn_amount_cell_data_function);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	// add column popup
-    g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 
 	column = list_txn_column_amount_create(list_type, _("Expense"), LST_DSPOPE_EXPENSE, list_txn_amount_cell_data_function);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	// add column popup
-    g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 
 	column = list_txn_column_amount_create(list_type, _("Income"), LST_DSPOPE_INCOME, list_txn_amount_cell_data_function);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	// add column popup
-    g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 
 	column = list_txn_column_text_create(list_type, _("Category"), LST_DSPOPE_CATEGORY, list_txn_category_cell_data_function, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	// add column popup
-    g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 
 	column = list_txn_column_text_create(list_type, _("Tags"), LST_DSPOPE_TAGS, list_txn_tags_cell_data_function, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	// add column popup
-    g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-		"button-press-event",
-		G_CALLBACK ( list_txn_column_popup_callback ),
-		data );
+	if(list_type == LIST_TXN_TYPE_BOOK)
+		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+			"button-press-event",
+			G_CALLBACK ( list_txn_column_popup_callback ),
+			data );
 
 	if(list_type == LIST_TXN_TYPE_BOOK)
 	{
@@ -1441,10 +1531,11 @@ GtkTreeViewColumn  *column, *col_acc = NULL, *col_status = NULL;
 		gtk_tree_view_column_set_clickable(column, FALSE);
 		gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 		// add column popup
-		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
-			"button-press-event",
-			G_CALLBACK ( list_txn_column_popup_callback ),
-			data );
+		if(list_type == LIST_TXN_TYPE_BOOK)
+			g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
+				"button-press-event",
+				G_CALLBACK ( list_txn_column_popup_callback ),
+				data );
 	}
 	
   /* column 9: empty */
