@@ -57,7 +57,7 @@ void list_txn_set_column_acc_visible(GtkTreeView *treeview, gboolean visible);
 Transaction *list_txn_get_surround_transaction(GtkTreeView *treeview, Transaction **prev, Transaction **next);
 Transaction *list_txn_get_active_transaction(GtkTreeView *treeview);
 
-GString *list_txn_to_string(GtkTreeView *treeview, gboolean clipboard);
+GString *list_txn_to_string(GtkTreeView *treeview, gboolean clipboard, gboolean incsplit, gboolean incacc);
 
 void list_txn_set_save_column_width(GtkTreeView *treeview, gboolean save_column_width);
 void list_txn_sort_force(GtkTreeSortable *sortable, gpointer user_data);
