@@ -58,11 +58,12 @@ struct repbalance_data
 
 	GtkWidget	*window;
 
-	GtkUIManager	*ui;
-	GtkActionGroup *actions;
-
 	GtkWidget	*TB_bar;
-
+	GtkWidget	*BT_list;
+	GtkWidget	*BT_line;
+	GtkWidget	*BT_detail;
+	GtkWidget	*BT_refresh;
+	
 	GtkWidget	*TX_info;
 	GtkWidget	*TX_daterange;
 	GtkWidget	*CM_minor;
@@ -92,4 +93,4 @@ struct repbalance_data
 GtkWidget *repbalance_window_new(gint32 accnum);
 
 
-#endif
\ No newline at end of file
+#endif
