@@ -61,7 +61,7 @@ static void repbudget_update_detail(GtkWidget *widget, gpointer user_data);
 static void repbudget_update_daterange(GtkWidget *widget, gpointer user_data);
 static void repbudget_update_chart(GtkWidget *widget, gpointer user_data);
 
-static GString *ui_list_repbudget_to_string(GtkTreeView *treeview, gboolean clipboard);
+static GString *ui_list_repbudget_to_string(GtkTreeView *treeview, gchar *title, gboolean clipboard);
 
 
 extern gchar *CYA_CATSUBCAT[];
@@ -314,13 +314,18 @@ static void repbudget_export_result_clipboard(GtkWidget *widget, gpointer user_d
 struct repbudget_data *data;
 GtkClipboard *clipboard;
 GString *node;
+gint tmpfor;
+gchar *title;
 
 	DB( g_print("\n[repbudget] export result clipboard\n") );
 
 	data = user_data;
 	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	node = ui_list_repbudget_to_string(GTK_TREE_VIEW(data->LV_report), TRUE);
+	tmpfor     = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_for));
+	title = _(CYA_CATSUBCAT[tmpfor]);
+	
+	node = ui_list_repbudget_to_string(GTK_TREE_VIEW(data->LV_report), title, TRUE);
 
 	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
 	gtk_clipboard_set_text(clipboard, node->str, node->len);
@@ -337,6 +342,7 @@ GString *node;
 GIOChannel *io;
 gchar *name;
 gint tmpfor;
+gchar *title;
 
 	DB( g_print("\n[repbudget] export result csv\n") );
 
@@ -352,7 +358,8 @@ gint tmpfor;
 		io = g_io_channel_new_file(filename, "w", NULL);
 		if(io != NULL)
 		{
-			node = ui_list_repbudget_to_string(GTK_TREE_VIEW(data->LV_report), FALSE);
+			title = _(CYA_CATSUBCAT[tmpfor]);
+			node = ui_list_repbudget_to_string(GTK_TREE_VIEW(data->LV_report), title, FALSE);
 			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 			g_io_channel_unref (io);
 			g_string_free(node, TRUE);
@@ -374,7 +381,7 @@ GString *node;
 	data = user_data;
 	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE);
+	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE, FALSE, FALSE);
 
 	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
 	gtk_clipboard_set_text(clipboard, node->str, node->len);
@@ -407,7 +414,7 @@ gint tmpfor;
 		io = g_io_channel_new_file(filename, "w", NULL);
 		if(io != NULL)
 		{
-			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE);
+			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE, FALSE, FALSE);
 			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 
 			g_io_channel_unref (io);
@@ -1405,7 +1412,7 @@ gint row;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-static GString *ui_list_repbudget_to_string(GtkTreeView *treeview, gboolean clipboard)
+static GString *ui_list_repbudget_to_string(GtkTreeView *treeview, gchar *title, gboolean clipboard)
 {
 GString *node;
 GtkTreeModel *model;
@@ -1417,7 +1424,7 @@ const gchar *format;
 
 	// header
 	format = (clipboard == TRUE) ? "%s\t%s\t%s\t%s\t\n" : "%s;%s;%s;%s;\n";
-	g_string_append_printf(node, format, _("Category"), _("Spent"), _("Budget"), _("Result"));
+	g_string_append_printf(node, format, (title == NULL) ? _("Category") : title, _("Spent"), _("Budget"), _("Result"));
 
 	model = gtk_tree_view_get_model(treeview);
 	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
