@@ -53,6 +53,7 @@ extern struct Preferences *PREFS;
 
 static void ui_repdist_date_change(GtkWidget *widget, gpointer user_data);
 static void ui_repdist_range_change(GtkWidget *widget, gpointer user_data);
+static void ui_repdist_setup_filter(struct ui_repdist_data *data);
 static void ui_repdist_detail(GtkWidget *widget, gpointer user_data);
 static void ui_repdist_update(GtkWidget *widget, gpointer user_data);
 static void ui_repdist_update_total(GtkWidget *widget, gpointer user_data);
@@ -66,7 +67,7 @@ static GtkWidget *ui_list_repdist_create(void);
 static void ui_repdist_update_daterange(GtkWidget *widget, gpointer user_data);
 static void ui_repdist_update_date_widget(GtkWidget *widget, gpointer user_data);
 
-static GString *ui_list_repdist_to_string(GtkTreeView *treeview, gboolean clipboard);
+static GString *ui_list_repdist_to_string(GtkTreeView *treeview, gchar *title, gboolean clipboard);
 static gint ui_list_repdist_compare_func (GtkTreeModel *model, GtkTreeIter  *a, GtkTreeIter  *b, gpointer      userdata);
 
 //test multi
@@ -164,20 +165,36 @@ gint tmpview;
 static void ui_repdist_action_filter(GtkToolButton *toolbutton, gpointer user_data)
 {
 struct ui_repdist_data *data = user_data;
+gint response_id;
+
+	DB( g_print("\n[repdist] filter\n") );
 
 	//debug
 	//create_deffilter_window(data->filter, TRUE);
-
-	if(ui_flt_manage_dialog_new(GTK_WINDOW(data->window), data->filter, TRUE, FALSE) != GTK_RESPONSE_REJECT)
+	response_id = ui_flt_manage_dialog_new(GTK_WINDOW(data->window), data->filter, TRUE, FALSE);
+	if( response_id != GTK_RESPONSE_REJECT)
 	{
+		if( response_id == 55 )	//reset
+		{
+			DB( g_print(" reset filter\n") );
+			ui_repdist_setup_filter(data);
+		}
+		else
+		{
+			if( data->filter->range == FLT_RANGE_OTHER )
+			{
+				filter_preset_daterange_set(data->filter, data->filter->range, 0);
+			}
+		}
+
+		g_signal_handler_block(data->CY_range, data->handler_id[HID_REPDIST_RANGE]);
+		hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), data->filter->range);
+		g_signal_handler_unblock(data->CY_range, data->handler_id[HID_REPDIST_RANGE]);
+
+
 		ui_repdist_compute(data->window, NULL);
 		ui_repdist_update_date_widget(data->window, NULL);
 		ui_repdist_update_daterange(data->window, NULL);
-
-		g_signal_handler_block(data->CY_range, data->handler_id[HID_REPDIST_RANGE]);
-		hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_OTHER);
-		g_signal_handler_unblock(data->CY_range, data->handler_id[HID_REPDIST_RANGE]);
-
 	}
 }
 
@@ -409,13 +426,18 @@ static void ui_repdist_export_result_clipboard(GtkWidget *widget, gpointer user_
 struct ui_repdist_data *data;
 GtkClipboard *clipboard;
 GString *node;
+gchar *title;
+gint tmpsrc;
 
 	DB( g_print("\n[repdist] export result clipboard\n") );
 
 	data = user_data;
 	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	node = ui_list_repdist_to_string(GTK_TREE_VIEW(data->LV_report), TRUE);
+	tmpsrc  = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_src));
+
+	title = hbtk_get_label(CYA_REPORT_SRC,tmpsrc);
+	node = ui_list_repdist_to_string(GTK_TREE_VIEW(data->LV_report), title, TRUE);
 
 	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
 	gtk_clipboard_set_text(clipboard, node->str, node->len);
@@ -430,7 +452,7 @@ struct ui_repdist_data *data;
 gchar *filename = NULL;
 GString *node;
 GIOChannel *io;
-gchar *name;
+gchar *name, *title;
 gint tmpsrc;
 
 	DB( g_print("\n[repdist] export result csv\n") );
@@ -449,7 +471,8 @@ gint tmpsrc;
 		io = g_io_channel_new_file(filename, "w", NULL);
 		if(io != NULL)
 		{
-			node = ui_list_repdist_to_string(GTK_TREE_VIEW(data->LV_report), FALSE);
+			title = hbtk_get_label(CYA_REPORT_SRC,tmpsrc);
+			node = ui_list_repdist_to_string(GTK_TREE_VIEW(data->LV_report), title, FALSE);
 			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 			g_io_channel_unref (io);
 			g_string_free(node, TRUE);
@@ -471,7 +494,7 @@ GString *node;
 	data = user_data;
 	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE);
+	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE, FALSE, FALSE);
 
 	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
 	gtk_clipboard_set_text(clipboard, node->str, node->len);
@@ -505,7 +528,7 @@ gint tmpsrc;
 		io = g_io_channel_new_file(filename, "w", NULL);
 		if(io != NULL)
 		{
-			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE);
+			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE, FALSE, FALSE);
 			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 
 			g_io_channel_unref (io);
@@ -771,7 +794,6 @@ GtkTreeIter  iter;
 		GtkTreeViewColumn *column = gtk_tree_view_get_column( GTK_TREE_VIEW(data->LV_report2), 0);
 		gtk_tree_view_column_set_title(column, hbtk_get_label(CYA_REPORT_SRC,tmpsrc));
 
-
 		if( tmpsrc == REPORT_SRC_SUBCATEGORY )
 		{
 		GList *l, *clist = category_glist_sorted(1);
@@ -1072,40 +1094,6 @@ struct ui_repdist_data *data;
 }
 
 
-/*
-**
-*/
-static void ui_repdist_setup(struct ui_repdist_data *data)
-{
-	DB( g_print("\n[repdist] setup\n") );
-
-	data->txn_queue = g_queue_new ();
-
-	data->filter = da_flt_malloc();
-	filter_reset(data->filter);
-
-
-	data->detail = PREFS->stat_showdetail;
-	data->legend = 1;
-	data->rate = PREFS->stat_showrate^1;
-
-
-	ui_repdist_toggle_rate(data->window, NULL);
-
-
-
-	/* 3.4 : make int transfer out of stats */
-	data->filter->option[FILTER_TYPE] = 2;
-	data->filter->type = FLT_TYPE_INTXFER;
-
-	filter_preset_daterange_set(data->filter, PREFS->date_range_rep, 0);
-	
-	ui_repdist_update_date_widget(data->window, NULL);
-
-}
-
-
-
 static void ui_repdist_selection(GtkTreeSelection *treeselection, gpointer user_data)
 {
 GtkTreeModel *model;
@@ -1233,6 +1221,37 @@ GtkWidget *toolbar, *button;
 }
 
 
+//reset the filter
+static void ui_repdist_setup_filter(struct ui_repdist_data *data)
+{
+	DB( g_print("\n[repdist] reset filter\n") );
+
+	filter_reset(data->filter);
+	filter_preset_daterange_set(data->filter, PREFS->date_range_rep, 0);
+	ui_repdist_update_date_widget(data->window, NULL);
+
+	/* 3.4 : make int transfer out of stats */
+	data->filter->option[FILTER_TYPE] = 2;
+	data->filter->type = FLT_TYPE_INTXFER;
+	
+}
+
+
+// setup default for our object/memory
+static void ui_repdist_setup(struct ui_repdist_data *data)
+{
+	DB( g_print("\n[repdist] setup\n") );
+
+	ui_repdist_setup_filter(data);
+	
+	data->detail = PREFS->stat_showdetail;
+	data->legend = 1;
+	data->rate = PREFS->stat_showrate^1;
+
+	ui_repdist_toggle_rate(data->window, NULL);
+}
+
+
 static gboolean ui_repdist_dispose(GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 struct ui_repdist_data *data = user_data;
@@ -1268,6 +1287,16 @@ struct WinGeometry *wg;
 }
 
 
+//allocate our object/memory
+static void ui_repdist_acquire(struct ui_repdist_data *data)
+{
+	DB( g_print("\n[repdist] acquire\n") );
+
+	data->txn_queue = g_queue_new ();
+	data->filter = da_flt_malloc();
+}
+
+
 // the window creation
 GtkWidget *ui_repdist_window_new(void)
 {
@@ -1283,6 +1312,8 @@ gint row;
 	data = g_malloc0(sizeof(struct ui_repdist_data));
 	if(!data) return NULL;
 
+	ui_repdist_acquire(data);
+
 	//disable define windows
 	GLOBALS->define_off++;
 	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
@@ -1674,7 +1705,7 @@ gint row;
 */
 
 
-static GString *ui_list_repdist_to_string(GtkTreeView *treeview, gboolean clipboard)
+static GString *ui_list_repdist_to_string(GtkTreeView *treeview, gchar *title, gboolean clipboard)
 {
 GString *node;
 GtkTreeModel *model;
@@ -1686,7 +1717,7 @@ const gchar *format;
 
 	// header
 	format = (clipboard == TRUE) ? "%s\t%s\t%s\t%s\n" : "%s;%s;%s;%s\n";
-	g_string_append_printf(node, format, _("Result"), _("Expense"), _("Income"), _("Balance"));
+	g_string_append_printf(node, format, (title == NULL) ? _("Result") : title, _("Expense"), _("Income"), _("Balance"));
 
 	model = gtk_tree_view_get_model(treeview);
 	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
