@@ -69,7 +69,7 @@ static void ui_reptime_update_daterange(GtkWidget *widget, gpointer user_data);
 static GtkWidget *ui_list_reptime_create(void);
 
 static gint ui_list_reptime_compare_func (GtkTreeModel *model, GtkTreeIter  *a, GtkTreeIter  *b, gpointer      userdata);
-static GString *ui_list_reptime_to_string(GtkTreeView *treeview, gboolean clipboard);
+static GString *ui_list_reptime_to_string(GtkTreeView *treeview, gchar *title, gboolean clipboard);
 
 
 HbKvData CYA_REPORT_SRC_TREND[] = { 
@@ -279,13 +279,18 @@ static void ui_reptime_export_result_clipboard(GtkWidget *widget, gpointer user_
 struct ui_reptime_data *data;
 GtkClipboard *clipboard;
 GString *node;
+gchar *title;
+gint tmpintvl;
 
 	DB( g_print("\n[reptime] export result clipboard\n") );
 
 	data = user_data;
 	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	node = ui_list_reptime_to_string(GTK_TREE_VIEW(data->LV_report), TRUE);
+	tmpintvl  = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_intvl));
+	title = hbtk_get_label(CYA_REPORT_INTVL, tmpintvl);
+
+	node = ui_list_reptime_to_string(GTK_TREE_VIEW(data->LV_report), title, TRUE);
 
 	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
 	gtk_clipboard_set_text(clipboard, node->str, node->len);
@@ -302,6 +307,8 @@ GString *node;
 GIOChannel *io;
 gchar *name;
 gint tmpsrc;
+gchar *title;
+gint tmpintvl;
 
 	DB( g_print("\n[reptime] export result csv\n") );
 
@@ -317,7 +324,10 @@ gint tmpsrc;
 		io = g_io_channel_new_file(filename, "w", NULL);
 		if(io != NULL)
 		{
-			node = ui_list_reptime_to_string(GTK_TREE_VIEW(data->LV_report), FALSE);
+			tmpintvl  = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_intvl));
+			title = hbtk_get_label(CYA_REPORT_INTVL, tmpintvl);
+
+			node = ui_list_reptime_to_string(GTK_TREE_VIEW(data->LV_report), title, FALSE);
 			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 			g_io_channel_unref (io);
 			g_string_free(node, TRUE);
@@ -339,7 +349,7 @@ GString *node;
 	data = user_data;
 	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE);
+	node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), TRUE, FALSE, FALSE);
 
 	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
 	gtk_clipboard_set_text(clipboard, node->str, node->len);
@@ -372,7 +382,7 @@ gint tmpsrc;
 		io = g_io_channel_new_file(filename, "w", NULL);
 		if(io != NULL)
 		{
-			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE);
+			node = list_txn_to_string(GTK_TREE_VIEW(data->LV_detail), FALSE, FALSE, FALSE);
 			g_io_channel_write_chars(io, node->str, -1, NULL, NULL);
 
 			g_io_channel_unref (io);
@@ -692,9 +702,11 @@ guint32 selkey;
 		{
 		Account *acc = da_acc_get(selkey);
 			if( acc != NULL )
+			{
 				kcur = acc->kcur;
-
-			gtk_chart_set_overdrawn(GTK_CHART(data->RE_line), acc->minimum);
+				//fix 5.4.2 crash here
+				gtk_chart_set_overdrawn(GTK_CHART(data->RE_line), acc->minimum);
+			}
 		}
 
 		ui_reptime_list_set_cur(GTK_TREE_VIEW(data->LV_report), kcur);
@@ -1422,7 +1434,7 @@ gint row;
 */
 
 
-static GString *ui_list_reptime_to_string(GtkTreeView *treeview, gboolean clipboard)
+static GString *ui_list_reptime_to_string(GtkTreeView *treeview, gchar *title, gboolean clipboard)
 {
 GString *node;
 GtkTreeModel *model;
@@ -1434,7 +1446,7 @@ const gchar *format;
 
 	// header
 	format = (clipboard == TRUE) ? "%s\t%s\n" : "%s;%s\n";
-	g_string_append_printf(node, format, _("Time slice"), _("Amount"));
+	g_string_append_printf(node, format, (title == NULL) ? _("Time slice") : title, _("Amount"));
 
 	model = gtk_tree_view_get_model(treeview);
 	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
