@@ -53,9 +53,10 @@ static void repvehicle_range_change(GtkWidget *widget, gpointer user_data);
 static void repvehicle_compute(GtkWidget *widget, gpointer user_data);
 static void repvehicle_update(GtkWidget *widget, gpointer user_data);
 static void repvehicle_toggle_minor(GtkWidget *widget, gpointer user_data);
+static void repvehicle_setup_categories(struct repvehicle_data *data, GArray *array);
 static void repvehicle_setup(struct repvehicle_data *data);
 static gboolean repvehicle_window_dispose(GtkWidget *widget, GdkEvent *event, gpointer user_data);
-static GtkWidget *create_list_repvehicle(void);
+static GtkWidget *list_vehicle_create(void);
 
 
 static void repvehicle_date_change(GtkWidget *widget, gpointer user_data)
@@ -139,36 +140,6 @@ gint retval;
 }
 
 
-//#1277622
-static CarCost *repvehicle_eval_memofield(CarCost *item, gchar *text)
-{
-gchar *d, *v1, *v2;
-gint len;
-
-	if( text != NULL)
-	{
-		len = strlen(text);
-		d = g_strstr_len(text, len, "d=");
-		v1 = g_strstr_len(text, len, "v=");
-		v2 = g_strstr_len(text, len, "v~");
-		if(d && (v1 || v2))
-		{
-			item->meter	= atol(d+2);
-			if(v1)
-			{
-				item->fuel	= g_strtod(v1+2, NULL);
-				item->partial = FALSE;
-			}
-			else
-			{
-				item->fuel	= g_strtod(v2+2, NULL);
-				item->partial = TRUE;
-			}
-		}
-	}
-	
-	return item;
-}
 
 
 static void repvehicle_export_csv(GtkWidget *widget, gpointer user_data)
@@ -251,11 +222,121 @@ gchar *outstr, *name;
 }
 
 
+//#1277622
+static gboolean
+repvehicle_eval_memofield(CarCost *item, gchar *text)
+{
+gboolean retval = FALSE;
+gchar *d, *v1, *v2;
+gint len;
+
+	if(item != NULL)
+	{
+		item->meter   = 0;
+		item->fuel    = 0.0;
+		item->partial = FALSE;
+	}
+	if( text != NULL)
+	{
+		//TODO: optim here
+		len = strlen(text);
+		d = g_strstr_len(text, len, "d=");
+		v1 = g_strstr_len(text, len, "v=");
+		v2 = g_strstr_len(text, len, "v~");
+		if(d && (v1 || v2))
+		{
+			retval = TRUE;
+			if(item != NULL)
+			{
+				item->meter	= atol(d+2);
+				if(v1)
+				{
+					item->fuel	= g_strtod(v1+2, NULL);
+				}
+				else
+				{
+					item->fuel	= g_strtod(v2+2, NULL);
+					item->partial = TRUE;
+				}
+			}
+		}
+	}
+	return retval;
+}
+
+
+static guint32
+compare_guint32_func (gconstpointer a, gconstpointer b)
+{
+	const guint32 *_a = a;
+	const guint32 *_b = b;
+
+	return *_a - *_b;
+}
+
+
+static gboolean
+my_g_array_exists(GArray *array, guint32 kcat)
+{
+gboolean retval = FALSE;
+
+#if( (GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION >= 62) )
+	retval = g_array_binary_search(array, &kcat, (GCompareFunc)compare_guint32_func, NULL);
+#else
+Category *cat;
+guint32 *key, i;
+
+	for(i=0;i<array->len;i++)
+	{
+		key = &g_array_index(array, guint32, i);
+		cat = da_cat_get(*key);
+		if( (cat != NULL) && (cat->key == kcat) )
+		{
+			retval = TRUE;
+			break;
+		}
+	}
+#endif
+
+	return retval;
+}
+
+
+
+static void
+my_garray_add(GArray *array, guint32 key)
+{
+Category *cat;
+
+	cat = da_cat_get(key);
+
+	if(!cat)
+		return;
+
+	//#1873660 add parent as well
+	if( cat->parent > 0 )
+	{
+		if( my_g_array_exists(array, cat->parent) == FALSE )
+		{
+			DB( g_print("  mark kcat=%d (parent)\n", cat->parent) );
+			g_array_append_vals(array, &cat->parent, 1);
+		}
+	}
+	
+	//add category
+	if( my_g_array_exists(array, cat->key) == FALSE )
+	{
+		DB( g_print("  mark kcat=%d\n", cat->key) );
+		g_array_append_vals(array, &cat->key, 1);
+	}
+}
+
+
 static void repvehicle_compute(GtkWidget *widget, gpointer user_data)
 {
 struct repvehicle_data *data;
+GArray *ga_cat;
 GList *list;
-guint32 catkey;
 
 	DB( g_print("\n[vehiclecost] compute\n") );
 
@@ -265,44 +346,88 @@ guint32 catkey;
 	da_vehiclecost_destroy(data->vehicle_list);
 	data->vehicle_list = NULL;
 
-	// get the category key
-	catkey = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_cat));
-	
-	/* do nothing if cat is 0 */
-	if( catkey == 0 )
-		goto end1;
-
-	DB( g_print(" -> active cat is %d\n", catkey) );
-
 	g_queue_free (data->txn_queue);
 	data->txn_queue = hbfile_transaction_get_partial(data->filter->mindate, data->filter->maxdate);
 
-	// collect transactions
-	// the purpose here is to collect all cat transaction
-	// and precompute item-> meter/fuel/partial
+	// pass1 to collect categories
+	ga_cat = g_array_new(FALSE, FALSE, sizeof(guint32));
+
+	list = g_queue_peek_head_link(data->txn_queue);
+	while (list != NULL)
+	{
+	Transaction *ope = list->data;
+
+		// eval normal transaction
+		if(!(ope->flags & OF_SPLIT))
+		{
+			if( repvehicle_eval_memofield(NULL, ope->memo) == TRUE )
+			{
+				my_garray_add(ga_cat, ope->kcat);
+			}
+		}
+		else
+		{
+		guint i, nbsplit = da_splits_length(ope->splits);
+		Split *split;
+
+			for(i=0;i<nbsplit;i++)
+			{
+				split = da_splits_get(ope->splits, i);
+				if( repvehicle_eval_memofield(NULL, split->memo) == TRUE )
+				{
+					my_garray_add(ga_cat, split->kcat);
+				}
+			}
+		}
+
+		list = g_list_next(list);
+	}
+
+
+	//here ga_cat contains cat+subcat of txn where there is vehicle cost data d= v=
+
+
+	// pass2: collect transactions + fill carcost items
 	list = g_queue_peek_head_link(data->txn_queue);
 	while (list != NULL)
 	{
 	Transaction *ope = list->data;
 	Category *cat;
-	CarCost *item;
+	CarCost tmp, *item;
 
+		//TODO: rely on a persistent flag // attribution ? 
 		// eval normal transaction
 		if(!(ope->flags & OF_SPLIT))
 		{
 			cat = da_cat_get(ope->kcat);
-			if( cat && (cat->key == catkey || cat->parent == catkey) )
+			if( (cat != NULL) )
 			{
-				item = da_vehiclecost_malloc();
-				item->date = ope->date;
-				item->memo = ope->memo;
-				// get amount in base currency
-				//item->amount = ope->amount;
-				item->amount = hb_amount_base(ope->amount, ope->kcur);
-
-				item = repvehicle_eval_memofield(item, ope->memo);
-				data->vehicle_list = g_list_prepend(data->vehicle_list, item);
-				DB( g_print(" -> store acc=%d '%s' %.2f\n", ope->kacc, ope->memo, ope->amount) );
+				if( (my_g_array_exists(ga_cat, cat->key) || my_g_array_exists(ga_cat, cat->parent) ) )
+				{
+					if( repvehicle_eval_memofield(&tmp, ope->memo) == TRUE )
+					{
+						item = da_vehiclecost_malloc();
+						item->kcat = ope->kcat;
+						item->date = ope->date;
+						item->memo = ope->memo;
+						item->amount = hb_amount_base(ope->amount, ope->kcur);
+						item->meter = tmp.meter;
+						item->fuel = tmp.fuel;
+						item->partial = tmp.partial;
+						data->vehicle_list = g_list_prepend(data->vehicle_list, item);
+						DB( g_print(" store txn kcat=%d acc=%d %4.2f '%s' \n", ope->kcat, ope->kacc, ope->amount, ope->memo) );
+					}
+					else
+					{
+						item = da_vehiclecost_malloc();
+						item->kcat = ope->kcat;
+						item->date = ope->date;
+						item->amount = hb_amount_base(ope->amount, ope->kcur);
+						item->meter = 0;
+						data->vehicle_list = g_list_prepend(data->vehicle_list, item);
+						DB( g_print(" store txn kcat=%d acc=%d %4.2f '%s' (other)\n", ope->kcat, ope->kacc, ope->amount, ope->memo) );
+					}
+				}
 			}
 		}
 		// eval split transaction
@@ -311,38 +436,52 @@ guint32 catkey;
 		guint i, nbsplit = da_splits_length(ope->splits);
 		Split *split;
 
-			DB( g_print(" -> nb split %d\n", nbsplit) );
-			
 			for(i=0;i<nbsplit;i++)
 			{
 				split = da_splits_get(ope->splits, i);
 				cat = da_cat_get(split->kcat);
-
-				DB( g_print(" -> eval split '%s'\n", split->memo) );
-				
-				if( cat && (cat->key == catkey || cat->parent == catkey) )
+				if( (cat != NULL) )
 				{
-					item = da_vehiclecost_malloc();
-					item->date = ope->date;
-					item->memo = split->memo;
-					// get amount in base currency
-					//item->amount = split->amount;
-					item->amount = hb_amount_base(split->amount, ope->kcur);
+					if( (my_g_array_exists(ga_cat, cat->key) || my_g_array_exists(ga_cat, cat->parent) ) )
+					{
+						if( repvehicle_eval_memofield(&tmp, split->memo) == TRUE )
+						{
+							item = da_vehiclecost_malloc();
+							item->kcat = split->kcat;
+							item->date = ope->date;
+							item->memo = split->memo;
+							item->amount = hb_amount_base(split->amount, ope->kcur);
+							item->meter = tmp.meter;
+							item->fuel = tmp.fuel;
+							item->partial = tmp.partial;
+							data->vehicle_list = g_list_prepend(data->vehicle_list, item);
+							DB( g_print(" store txn kcat=%d acc=%d %4.2f '%s' (split)\n", split->kcat, ope->kacc, split->amount, split->memo) );
+						}
+						else
+						{
+							item = da_vehiclecost_malloc();
+							item->kcat = split->kcat;
+							item->date = ope->date;
+							item->amount = hb_amount_base(split->amount, ope->kcur);
+							item->meter = tmp.meter;
+							data->vehicle_list = g_list_prepend(data->vehicle_list, item);
+							DB( g_print("- store txn kcat=%d acc=%d %4.2f '%s' (other plit)\n", ope->kcat, ope->kacc, ope->amount, ope->memo) );
+						}
+					}
+				}				
 
-					item = repvehicle_eval_memofield(item, split->memo);
-					data->vehicle_list = g_list_prepend(data->vehicle_list, item);
-					DB( g_print(" -> store split part acc=%d '%s' %.2f\n", ope->kacc, split->memo, split->amount) );
-				}
 			}
 		}
 
 		list = g_list_next(list);
 	}
 
+	repvehicle_setup_categories(data, ga_cat);
+	g_array_free(ga_cat, TRUE);
+
 	// sort by meter #399170
 	data->vehicle_list = g_list_sort(data->vehicle_list, (GCompareFunc)repvehicle_transaction_compare_func);
 
-end1:
 	repvehicle_update(widget, NULL);
 }
 
@@ -354,6 +493,7 @@ GtkTreeModel *model;
 GtkTreeIter  iter;
 GList *list;
 gchar *buf;
+guint32 selkey;
 gint nb_refuel = 0;
 int nb_fullrefuel = 0; 
 guint lastmeter = 0;
@@ -362,6 +502,11 @@ guint lastmeter = 0;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
+	// get the category key
+	selkey = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_cat));
+
+	DB( g_print(" selkey=%d\n\n", selkey) );
+
 	// clear and detach our model
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report));
 	gtk_list_store_clear (GTK_LIST_STORE(model));
@@ -376,18 +521,28 @@ guint lastmeter = 0;
 	gdouble partial_fuel = 0;
 	guint	partial_dist = 0;
 
+	if( selkey == 0 )
+		goto noselkey;
+
 
 	list = g_list_first(data->vehicle_list);
 	while (list != NULL)
 	{
 	CarCost *item = list->data;
+	Category *itemcat;
 	gint dist;
 	gdouble centkm;
 	guint distbyvol;
 	gdouble trn_amount;
 
-		if( (item->date >= data->filter->mindate) && (item->date <= data->filter->maxdate) )
+		itemcat = da_cat_get(item->kcat);
+		if(! itemcat )
+			continue;
+
+		if( (itemcat->key == selkey || itemcat->parent == selkey) )
 		{
+			DB( g_print(" add treeview kcat=%d %s\n", item->kcat, item->memo) );
+
 			trn_amount = item->amount;
 
 			if( item->meter == 0 )
@@ -410,8 +565,8 @@ guint lastmeter = 0;
 				lastmeter = item->meter;
 				nb_refuel++;
 
-				DB( g_print("\n eval %02d :: d=%d v=%.2f $%.2f dist=%d\n", nb_refuel, item->meter, item->fuel, trn_amount, item->dist) );
-				DB( g_print(" + %s :: pf=%.2f pd=%d\n", item->partial ? "partial" : "full", partial_fuel, partial_dist) );
+				//DB( g_print("\n eval %02d :: d=%d v=%.2f $%.2f dist=%d\n", nb_refuel, item->meter, item->fuel, trn_amount, item->dist) );
+				//DB( g_print(" + %s :: pf=%.2f pd=%d\n", item->partial ? "partial" : "full", partial_fuel, partial_dist) );
 
 				centkm = 0;
 				dist = 0;
@@ -429,13 +584,13 @@ guint lastmeter = 0;
 							partial_dist += item->dist;
 							dist = item->dist;
 							centkm = partial_dist != 0 ? partial_fuel * 100 / partial_dist : 0;
-							DB( g_print(" + centkm=%.2f %.2f * 100 / %d (full after partial)\n", centkm, partial_fuel, partial_dist) );
+							//DB( g_print(" + centkm=%.2f %.2f * 100 / %d (full after partial)\n", centkm, partial_fuel, partial_dist) );
 						}
 						else
 						{
 							dist = item->dist;
 							centkm = item->dist != 0 ? item->fuel * 100 / item->dist : 0;
-							DB( g_print(" + centkm=%.2f :: %.2f * 100 / %d (full after full)\n", centkm, item->fuel, item->dist) );
+							//DB( g_print(" + centkm=%.2f :: %.2f * 100 / %d (full after full)\n", centkm, item->fuel, item->dist) );
 						}
 					}
 					partial_fuel = 0;
@@ -448,7 +603,7 @@ guint lastmeter = 0;
 					partial_fuel += item->fuel;
 					partial_dist += item->dist;
 					dist = item->dist;
-					DB( g_print(" + centkm= not computable\n") );
+					//DB( g_print(" + centkm= not computable\n") );
 				}
 
 				distbyvol = 0;
@@ -486,6 +641,8 @@ guint lastmeter = 0;
 		list = g_list_next(list);
 	}
 
+
+noselkey:
 	gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_report), model);
 	g_object_unref(model);
 
@@ -556,6 +713,7 @@ guint lastmeter = 0;
 
 }
 
+
 static void repvehicle_toggle_minor(GtkWidget *widget, gpointer user_data)
 {
 struct repvehicle_data *data;
@@ -581,9 +739,50 @@ struct repvehicle_data *data;
 
 }
 
-/*
-**
-*/
+
+static void repvehicle_setup_categories(struct repvehicle_data *data, GArray *array)
+{
+Category *cat;
+guint32 kcat, *key, i;
+
+	DB( g_print("\n[vehiclecost] setup categories\n") );
+
+	kcat = GLOBALS->vehicle_category;
+
+	g_signal_handler_block(data->PO_cat, data->handler_id[HID_REPVEHICLE_VEHICLE]);
+
+	if( array != NULL )
+	{
+		//get previous category
+		kcat = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_cat));
+
+		//populate with the array
+		ui_cat_combobox_entry_clear(GTK_COMBO_BOX(data->PO_cat));
+
+		cat = da_cat_get(0);
+		if(cat)
+		{
+			DB( g_print(" add %d '%s'\n", cat->key, cat->fullname) );
+			ui_cat_comboboxentry_add(GTK_COMBO_BOX(data->PO_cat), cat);
+		}
+
+		for(i=0;i<array->len;i++)
+		{
+			key = &g_array_index(array, guint32, i);
+			cat = da_cat_get(*key);
+			if(cat)
+			{
+				DB( g_print(" add %d %s\n", cat->key, cat->fullname) );
+				ui_cat_comboboxentry_add(GTK_COMBO_BOX(data->PO_cat), cat);
+			}
+		}
+	}
+
+	ui_cat_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_cat), kcat);
+	g_signal_handler_unblock(data->PO_cat, data->handler_id[HID_REPVEHICLE_VEHICLE]);
+}
+
+
 static void repvehicle_setup(struct repvehicle_data *data)
 {
 	DB( g_print("\n[vehiclecost] setup\n") );
@@ -609,14 +808,7 @@ static void repvehicle_setup(struct repvehicle_data *data)
 	g_signal_handler_unblock(data->PO_mindate, data->handler_id[HID_REPVEHICLE_MINDATE]);
 	g_signal_handler_unblock(data->PO_maxdate, data->handler_id[HID_REPVEHICLE_MAXDATE]);
 
-
-	ui_cat_comboboxentry_populate(GTK_COMBO_BOX(data->PO_cat), GLOBALS->h_cat);
-
-	g_signal_handler_block(data->PO_cat, data->handler_id[HID_REPVEHICLE_VEHICLE]);
-	ui_cat_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_cat), GLOBALS->vehicle_category);
-	g_signal_handler_unblock(data->PO_cat, data->handler_id[HID_REPVEHICLE_VEHICLE]);
-
-
+	repvehicle_setup_categories(data, NULL);
 
 }
 
@@ -833,7 +1025,7 @@ gint row, col;
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-	treeview = create_list_repvehicle();
+	treeview = list_vehicle_create();
 	data->LV_report = treeview;
 	gtk_container_add (GTK_CONTAINER(widget), treeview);
     gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
@@ -859,7 +1051,7 @@ gint row, col;
 
 	data->handler_id[HID_REPVEHICLE_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (repvehicle_range_change), NULL);
 
-	data->handler_id[HID_REPVEHICLE_VEHICLE] = g_signal_connect (data->PO_cat, "changed", G_CALLBACK (repvehicle_compute), NULL);
+	data->handler_id[HID_REPVEHICLE_VEHICLE] = g_signal_connect (data->PO_cat, "changed", G_CALLBACK (repvehicle_update), NULL);
 
 	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (repvehicle_action_refresh), (gpointer)data);
 	g_signal_connect (G_OBJECT (data->BT_export) , "clicked", G_CALLBACK (repvehicle_action_export), (gpointer)data);
@@ -901,7 +1093,7 @@ gint row, col;
 ** ============================================================================
 */
 
-static void repvehicle_date_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void list_vehicle_cell_data_func_date (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 GDate *date;
 guint32 julian;
@@ -918,7 +1110,7 @@ gchar buf[256];
 	g_object_set(renderer, "text", buf, NULL);
 }
 
-static void repvehicle_distance_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void list_vehicle_cell_data_func_distance (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 guint distance;
 gchar *text;
@@ -935,7 +1127,7 @@ gchar *text;
 		g_object_set(renderer, "text", "-", NULL);
 }
 
-static void repvehicle_volume_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void list_vehicle_cell_data_func_volume (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 gdouble volume;
 gboolean partial;
@@ -958,7 +1150,7 @@ gchar *text;
 		g_object_set(renderer, "text", "-", NULL);
 }
 
-static void repvehicle_amount_cell_data_function (GtkTreeViewColumn *col,
+static void list_vehicle_cell_data_func_amount (GtkTreeViewColumn *col,
                            GtkCellRenderer   *renderer,
                            GtkTreeModel      *model,
                            GtkTreeIter       *iter,
@@ -988,7 +1180,7 @@ gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
 	}
 }
 
-static GtkTreeViewColumn *volume_list_repvehicle_column(gchar *name, gint id)
+static GtkTreeViewColumn *list_vehicle_column_volume(gchar *name, gint id)
 {
 GtkTreeViewColumn  *column;
 GtkCellRenderer    *renderer;
@@ -998,13 +1190,13 @@ GtkCellRenderer    *renderer;
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, repvehicle_volume_cell_data_function, GINT_TO_POINTER(id), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_vehicle_cell_data_func_volume, GINT_TO_POINTER(id), NULL);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	//gtk_tree_view_column_set_sort_column_id (column, id);
 	return column;
 }
 
-static GtkTreeViewColumn *distance_list_repvehicle_column(gchar *name, gint id)
+static GtkTreeViewColumn *list_vehicle_column_distance(gchar *name, gint id)
 {
 GtkTreeViewColumn  *column;
 GtkCellRenderer    *renderer;
@@ -1014,13 +1206,13 @@ GtkCellRenderer    *renderer;
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, repvehicle_distance_cell_data_function, GINT_TO_POINTER(id), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_vehicle_cell_data_func_distance, GINT_TO_POINTER(id), NULL);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	//gtk_tree_view_column_set_sort_column_id (column, id);
 	return column;
 }
 
-static GtkTreeViewColumn *amount_list_repvehicle_column(gchar *name, gint id)
+static GtkTreeViewColumn *list_vehicle_column_amount(gchar *name, gint id)
 {
 GtkTreeViewColumn  *column;
 GtkCellRenderer    *renderer;
@@ -1030,7 +1222,7 @@ GtkCellRenderer    *renderer;
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, repvehicle_amount_cell_data_function, GINT_TO_POINTER(id), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_vehicle_cell_data_func_amount, GINT_TO_POINTER(id), NULL);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	//gtk_tree_view_column_set_sort_column_id (column, id);
 	return column;
@@ -1040,7 +1232,7 @@ GtkCellRenderer    *renderer;
 /*
 ** create our statistic list
 */
-static GtkWidget *create_list_repvehicle(void)
+static GtkWidget *list_vehicle_create(void)
 {
 GtkListStore *store;
 GtkWidget *view;
@@ -1076,7 +1268,7 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	//gtk_tree_view_column_add_attribute(column, renderer, "text", LST_CAR_DATE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, repvehicle_date_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_vehicle_cell_data_func_date, NULL, NULL);
 
 /*
 	LST_CAR_DATE,
@@ -1102,31 +1294,31 @@ GtkTreeViewColumn  *column;
 */
 
 	/* column: Meter */
-	column = distance_list_repvehicle_column(_("Meter"), LST_CAR_METER);
+	column = list_vehicle_column_distance(_("Meter"), LST_CAR_METER);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 	/* column: Fuel load */
-	column = volume_list_repvehicle_column(_("Fuel"), LST_CAR_FUEL);
+	column = list_vehicle_column_volume(_("Fuel"), LST_CAR_FUEL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 	/* column: Price by unit */
-	column = amount_list_repvehicle_column(_("Price"), LST_CAR_PRICE);
+	column = list_vehicle_column_amount(_("Price"), LST_CAR_PRICE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 	/* column: Amount */
-	column = amount_list_repvehicle_column(_("Amount"), LST_CAR_AMOUNT);
+	column = list_vehicle_column_amount(_("Amount"), LST_CAR_AMOUNT);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 	/* column: Distance done */
-	column = distance_list_repvehicle_column(_("Dist."), LST_CAR_DIST);
+	column = list_vehicle_column_distance(_("Dist."), LST_CAR_DIST);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 	/* column: consumption for 100Km */
-	column = volume_list_repvehicle_column(PREFS->vehicle_unit_100, LST_CAR_100KM);
+	column = list_vehicle_column_volume(PREFS->vehicle_unit_100, LST_CAR_100KM);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 	/* column: km by liter (distance by volume */
-	column = distance_list_repvehicle_column(PREFS->vehicle_unit_distbyvol, LST_CAR_DISTBYVOL);
+	column = list_vehicle_column_distance(PREFS->vehicle_unit_distbyvol, LST_CAR_DISTBYVOL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
 
 
