@@ -114,7 +114,7 @@ GtkWidget *entry;
 GtkTreeModel *model;
 GtkTreeIter iter;
 
-	DB( g_print ("ui_acc_comboboxentry_set_single()\n") );
+	DB( g_print ("ui_acc_popover_set_single()\n") );
 
 	entry = container_get_nth(box, 0);
 	if( entry != NULL && GTK_IS_ENTRY(entry) )
@@ -140,7 +140,7 @@ ui_acc_entry_popover_set_active(GtkBox *box, guint32 key)
 {
 GtkWidget *entry;
 
-	DB( g_print ("ui_acc_comboboxentry_set_active()\n") );
+	DB( g_print ("ui_acc_popover_set_active()\n") );
 
 	entry = container_get_nth(box, 0);
 	if( entry != NULL && GTK_IS_ENTRY(entry) )
@@ -218,7 +218,7 @@ struct accPopContext ctx;
 
 	model = ui_acc_entry_popover_get_model(GTK_BOX(box));
 	
-	/* keep our model alive and detach from comboboxentry and completion */
+	/* keep our model alive and detach from popover and completion */
 	g_object_ref(model);
 
 	/* clear and populate */
