@@ -21,13 +21,6 @@
 #define __HB_ARCHIVE_GTK_H__
 
 
-enum
-{
-	ARC_TYPE_ALL = 0,
-	ARC_TYPE_SCHEDULED,
-	ARC_TYPE_TEMPLATE
-};
-
 #define LST_DEFARC_SORT_DATE    1
 #define LST_DEFARC_SORT_MEMO    2
 #define LST_DEFARC_SORT_PAYEE   3
@@ -50,9 +43,9 @@ struct ui_arc_manage_data
 	GList	*tmp_list;
 	gint	change;
 
+	GtkWidget	*BT_typsch, *BT_typtpl;
 	GtkWidget	*ST_search;
 	GtkWidget	*LV_arc;
-	GtkWidget	*RA_flttype;
 	GtkWidget	*BT_add, *BT_edit, *BT_rem;
 
 	GtkWidget	*MB_schedule;
