@@ -111,7 +111,7 @@ gchar *string;
 		name = entry->search;
 
 	#if MYDEBUG
-		string = g_strdup_printf ("[%d] %s", entry->key, name );
+		string = g_strdup_printf ("k[%d] p[%d] %s", entry->key, entry->pos, name );
 		g_object_set(renderer, "text", string, NULL);
 		g_free(string);
 	#else
@@ -225,7 +225,7 @@ GList *lrul, *list;
 	{
 	Assign *item = list->data;
 
-		DB( g_print(" populate: %d\n", item->key) );
+		DB( g_print(" populate: k%d p%d '%s'\n", item->key, item->pos, item->notes) );
 
 		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
