@@ -19,6 +19,7 @@
 
 #include "homebank.h"
 
+#include "hub-account.h"
 #include "hb-import.h"
 #include "ui-assist-import.h"
 #include "dsp-mainwindow.h"
@@ -1257,6 +1258,15 @@ gboolean visible;
 		ui_genacc_comboboxtext_set_active(txndata->CY_acc, genacc->kacc);
 		g_signal_handlers_unblock_by_func(txndata->CY_acc, G_CALLBACK(ui_import_page_transaction_cb_account_changed), NULL);
 
+		g_signal_handlers_block_by_func(txndata->NB_txn_daygap, G_CALLBACK(ui_import_page_transaction_cb_account_changed), NULL);
+		ictx->opt_daygap = PREFS->dtex_daygap;
+
+		DB( g_print(" init %d to dategap\n", ictx->opt_daygap) );
+
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(txndata->NB_txn_daygap), ictx->opt_daygap);
+		g_signal_handlers_unblock_by_func(txndata->NB_txn_daygap, G_CALLBACK(ui_import_page_transaction_cb_account_changed), NULL);
+
+
 		ui_import_page_transaction_options_get(data);
 		hb_import_option_apply(ictx, genacc);
 		if( genacc->is_dupcheck == FALSE )
@@ -1526,7 +1536,7 @@ gchar *txt;
 	widget = gtk_image_new_from_icon_name(ICONNAME_ERROR, GTK_ICON_SIZE_DIALOG );
 	gtk_box_pack_start (GTK_BOX (mainbox), widget, FALSE, FALSE, 0);
 	
-	txt = _("There is too much account in the files you choosed,\n" \
+	txt = _("There is too much account in the files you choose,\n" \
 			"please use the back button to select less files.");
 	label = gtk_label_new(txt);
 	gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
@@ -2132,7 +2142,11 @@ ImportContext *ictx;
 	//#1845388 persist options for lazy people
 	PREFS->dtex_dodefpayee = ictx->do_auto_payee;
 	PREFS->dtex_doautoassign = ictx->do_auto_assign;
-	
+
+	PREFS->dtex_daygap = ictx->opt_daygap;
+	DB( g_print(" strore %d to dategap\n", PREFS->dtex_dategap) );
+
+
 	hb_import_apply(&data->ictx);
 }
 
@@ -2163,7 +2177,9 @@ struct import_data *data = user_data;
 		//GLOBALS->changes_count += data->imp_cnt_trn;
 
 		//our global list has changed, so update the treeview
-		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_BALANCE+UF_REFRESHALL));
+		account_compute_balances ();
+		ui_hub_account_populate(GLOBALS->mainwindow, NULL);
+		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE+UF_REFRESHALL));
 	//}
 
 	g_free(user_data);
