@@ -21,32 +21,41 @@
 #define __HB_UI_ASSIST_START_GTK_H__
 
 
+#define PAGE_WELCOME		0
+#define PAGE_GENERAL		1
+#define PAGE_CURRENCIES		2
+#define PAGE_CATEGORIES		3
+#define PAGE_ACCOUNTS		4
+
+
 struct assist_start_data
 {
-	GtkWidget	*window;
+	GtkWidget	*dialog;
 	//GtkWidget	*pages[NUM_PAGE];
 	GtkWidget	*ST_owner;
-	GtkWidget   *LB_currency;
-	GtkWidget   *BT_change;
 
-	GtkWidget	*TX_lang;
+	GtkWidget   *LB_cur_base, *BT_cur_change;;
+	GtkWidget	*CM_cur_add, *LB_cur_others, *BT_cur_add;
+
+	GtkWidget	*GR_file;
 	GtkWidget	*TX_file;
+	GtkWidget	*TX_preview;
 	GtkWidget	*ok_image, *ko_image;
 	GtkWidget	*CM_load;
 
+	GtkWidget	*CM_acc_add;
+	GtkWidget	*GR_acc;
 	GtkWidget	*ST_name;
 	GtkWidget	*CY_type;
-	GtkWidget	*ST_number;
-	GtkWidget	*ST_initial;
-	GtkWidget	*ST_minimum;
 
 	Currency4217 *curfmt;
-	gchar	   *pathfilename;
+	gchar		*pathfilename;
+	GPtrArray	*cur_arr;
 };
 
 
 
-GtkWidget *ui_start_assistant(void);
+GtkWidget *ui_newfile_assitant_new(void);
 
 
 #endif
