@@ -328,7 +328,7 @@ char buf[G_ASCII_DTOSTR_BUF_SIZE];
 }
 
 
-static gint ui_bud_manage_category_exists (GtkTreeModel *model, gchar *level, gchar *type, gchar *name, GtkTreeIter *return_iter)
+static gint ui_bud_manage_category_exists (GtkTreeModel *model, gchar *level, gchar *type, gchar *fullname, GtkTreeIter *return_iter)
 {
 GtkTreeIter  iter, child;
 gboolean     valid;
@@ -346,7 +346,7 @@ gint pos = 0;
 
 		if(*level == '1')
 		{
-			if(entry->name && g_ascii_strcasecmp(name, entry->name) == 0)
+			if(entry->fullname && g_ascii_strcasecmp(fullname, entry->fullname) == 0)
 			{
 				*return_iter = iter;
 				return pos;
@@ -365,7 +365,7 @@ gint pos = 0;
 						LST_DEFCAT_DATAS, &entry,
 						-1);
 
-					if(entry->name && g_ascii_strcasecmp(name, entry->name) == 0)
+					if(entry->fullname && g_ascii_strcasecmp(fullname, entry->fullname) == 0)
 					{
 						*return_iter = child;
 						return pos;
@@ -574,7 +574,7 @@ GIOChannel *io;
 						type = (category->flags & GF_CUSTOM) ? ' ' : '*';
 
 						outvalstr = ui_bud_manage_getcsvbudgetstr(category);
-						outstr = g_strdup_printf("1;%c;%s;%s\n", type, category->name, outvalstr);
+						outstr = g_strdup_printf("1;%c;%s;%s\n", type, category->fullname, outvalstr);
 						DB( g_print("%s", outstr) );
 						g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
 						g_free(outstr);
@@ -594,7 +594,7 @@ GIOChannel *io;
 						outvalstr = ui_bud_manage_getcsvbudgetstr(category);
 						if( outvalstr )
 						{
-							outstr = g_strdup_printf("2;%c;%s;%s\n", type, category->name, outvalstr);
+							outstr = g_strdup_printf("2;%c;%s;%s\n", type, category->fullname, outvalstr);
 							DB( g_print("%s", outstr) );
 							g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
 							g_free(outstr);
@@ -1084,7 +1084,7 @@ GtkWidget *menu, *menuitem, *widget, *image, *tbar;
 GtkToolItem *toolitem;
 GList *fchain;
 guint i;
-gint w, h;
+gint w, h, dw, dh;
 gint crow, row;
 
 	data = g_malloc0(sizeof(struct ui_bud_manage_data));
@@ -1103,8 +1103,11 @@ gint crow, row;
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
-	gtk_window_set_default_size (GTK_WINDOW(dialog), -1, h/PHI);
-
+	dh = (h*1.33/PHI);
+	//ratio 3:2
+	dw = (dh * 3) / 2;
+	DB( g_print(" main w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
+	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
 	
 	//store our window private data
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
