@@ -113,7 +113,7 @@ GtkTreeModel *store;
 			store = gtk_entry_completion_get_model(gtk_entry_get_completion(GTK_ENTRY(entry)));
 			if( store )
 				gtk_list_store_insert_with_values(GTK_LIST_STORE(store), NULL, -1,
-					0, item->name,
+					0, item->fullname,
 					1, item,
 					-1);
 			return item->key;
@@ -138,7 +138,7 @@ ui_cat_entry_popover_set_active(GtkBox *box, guint32 key)
 {
 GtkWidget *entry;
 
-	DB( g_print ("ui_cat_comboboxentry_set_active()\n") );
+	DB( g_print ("[cat entry popover] setactive\n") );
 
 	entry = container_get_nth(box, 0);
 	if( entry != NULL && GTK_IS_ENTRY(entry) )
@@ -337,7 +337,7 @@ static void
 ui_cat_entry_popover_destroy( GtkWidget *widget, gpointer user_data )
 {
 
-    DB( g_print ("[pay entry popover] destroy\n") );
+    DB( g_print ("[cat entry popover] destroy\n") );
 
 }
 
@@ -1042,16 +1042,19 @@ ui_cat_listview_count_cell_data_function (GtkTreeViewColumn *col,
 				gpointer user_data)
 {
 Category *entry;
-gchar buffer[256];
+gchar buffer[32];
 
+	buffer[0] = '\0';
 	gtk_tree_model_get(model, iter, LST_DEFCAT_DATAS, &entry, -1);
 	if(entry->usage_count > 0)
 	{
-		g_snprintf(buffer, 256-1, "%d", entry->usage_count);
-		g_object_set(renderer, "text", buffer, NULL);
+		if( !(entry->flags & GF_SUB) && (entry->usage_catcount != entry->usage_count) ) 
+			g_snprintf(buffer, 32-1, "%d (%d)", entry->usage_count, entry->usage_catcount);
+		else
+			g_snprintf(buffer, 32-1, "%d", entry->usage_count);
 	}
-	else
-		g_object_set(renderer, "text", "", NULL);
+
+	g_object_set(renderer, "text", buffer, NULL);
 }
 
 
@@ -1812,7 +1815,7 @@ static void ui_cat_manage_dialog_merge(GtkWidget *widget, gpointer user_data)
 {
 struct ui_cat_manage_dialog_data *data;
 GtkWidget *dialog, *content, *mainvbox;
-GtkWidget *getwidget, *togglebutton;
+GtkWidget *getwidget, *cb_subcat, *togglebutton;
 GtkTreeSelection *selection;
 GtkTreeModel *model;
 GtkTreeIter iter;
@@ -1861,6 +1864,9 @@ GtkTreeIter iter;
 		getwidget = ui_cat_comboboxentry_new(NULL);
 		gtk_box_pack_start (GTK_BOX (mainvbox), getwidget, FALSE, FALSE, 0);
 
+		cb_subcat = gtk_check_button_new_with_mnemonic(_("Include _subcategories"));
+		gtk_box_pack_start (GTK_BOX (mainvbox), cb_subcat, FALSE, FALSE, 0);
+
 		secondtext = g_strdup_printf (
 			_("_Delete the category '%s'"), srccat->name);
 		togglebutton = gtk_check_button_new_with_mnemonic(secondtext);
@@ -1877,7 +1883,9 @@ GtkTreeIter iter;
 		gtk_widget_grab_focus (getwidget);
 
 		gtk_widget_show_all(mainvbox);
-		
+
+		hb_widget_visible(cb_subcat, (srccat->flags & GF_SUB) ? FALSE : TRUE);
+
 		//wait for the user
 		gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -1885,21 +1893,23 @@ GtkTreeIter iter;
 		{
 		GtkTreeModel *model;
 		Category *newcat, *parent;
+		gboolean dosubcat;
 		guint dstcatkey;
 
-
 			model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_cat));
 			gtk_tree_store_clear (GTK_TREE_STORE(model));
 
 			dstcatkey = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX(getwidget));
+			dosubcat = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(cb_subcat));
 
-			DB( g_print(" -> move cat to %d\n", dstcatkey) );
+			DB( g_print(" -> move cat to %d (subcat=%d)\n", dstcatkey, dosubcat) );
 
-			category_move(srccat->key, dstcatkey);
+			category_move(srccat->key, dstcatkey, dosubcat);
 
 			newcat = da_cat_get (dstcatkey);
 
 			//#1771720: update count
+			//TODO: this is imperfect here, as if subcat, we don't count ?
 			newcat->usage_count += srccat->usage_count;
 			srccat->usage_count = 0;
 			
@@ -1974,7 +1984,7 @@ gint result;
 		if( result == GTK_RESPONSE_OK )
 		{
 			ui_cat_listview_remove_selected(GTK_TREE_VIEW(data->LV_cat));
-			category_move(item->key, 0);
+			category_move(item->key, 0, TRUE);
 			da_cat_delete(item->key);
 			data->change++;
 		}
