@@ -1220,40 +1220,40 @@ gint crow, row;
 	gtk_tree_view_column_set_sort_column_id (column, LST_CURSEL_ISO);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
-	if( select_mode == CUR_SELECT_MODE_NORMAL )
-	{
-		// group :: Custom
-		row++;
-		widget = gtk_check_button_new_with_mnemonic (_("Add a custom _currency"));
-		data->CM_custom = widget;
-		gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 4, 1);
-		
-		//custom currency (crypto and discontinued)
-		row++;
-		label = make_label_widget(_("_Name:"));
-		data->LB_custname = label;
-		gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-		widget = make_string(label);
-		data->ST_custname = widget;
-		gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
-
-		label = make_label_widget(_("_ISO:"));
-		data->LB_custiso = label;
-		gtk_grid_attach (GTK_GRID (group_grid), label, 3, row, 1, 1);
-		widget = make_string_maxlength(label, 3);
-		data->ST_custiso = widget;
-		gtk_grid_attach (GTK_GRID (group_grid), widget, 4, row, 1, 1);
-
-		g_signal_connect (G_OBJECT (data->CM_custom)  , "toggled", G_CALLBACK (ui_cur_select_custom_activate_cb), data);	
-		g_signal_connect (G_OBJECT (data->ST_custname), "changed", G_CALLBACK (ui_cur_select_custom_validate_cb), data);
-		g_signal_connect (G_OBJECT (data->ST_custiso) , "changed", G_CALLBACK (ui_cur_select_custom_validate_cb), data);
+	// group :: Custom
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("Add a custom _currency"));
+	data->CM_custom = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 4, 1);
 	
+	//custom currency (crypto and discontinued)
+	row++;
+	label = make_label_widget(_("_Name:"));
+	data->LB_custname = label;
+	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
+	widget = make_string(label);
+	data->ST_custname = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+	label = make_label_widget(_("_ISO:"));
+	data->LB_custiso = label;
+	gtk_grid_attach (GTK_GRID (group_grid), label, 3, row, 1, 1);
+	widget = make_string_maxlength(label, 3);
+	data->ST_custiso = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 4, row, 1, 1);
+
+	g_signal_connect (G_OBJECT (data->CM_custom)  , "toggled", G_CALLBACK (ui_cur_select_custom_activate_cb), data);	
+	g_signal_connect (G_OBJECT (data->ST_custname), "changed", G_CALLBACK (ui_cur_select_custom_validate_cb), data);
+	g_signal_connect (G_OBJECT (data->ST_custiso) , "changed", G_CALLBACK (ui_cur_select_custom_validate_cb), data);
+	
+	gtk_window_resize(GTK_WINDOW(dialog), 400/PHI, 400);
+	gtk_widget_show_all(content_area);
+
+	if( select_mode != CUR_SELECT_MODE_CUSTOM )
+	{
+		hb_widget_visible (data->CM_custom, FALSE);
 	}
 
-	gtk_window_resize(GTK_WINDOW(dialog), 400/PHI, 400);
-
-
-	gtk_widget_show_all(content_area);
 	hb_widget_visible (data->LB_custname, FALSE);
 	hb_widget_visible (data->ST_custname, FALSE);
 	hb_widget_visible (data->LB_custiso, FALSE);
@@ -1424,7 +1424,7 @@ gboolean added;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	result = ui_cur_select_dialog_new(GTK_WINDOW(data->dialog), CUR_SELECT_MODE_NORMAL, &selectCtx);
+	result = ui_cur_select_dialog_new(GTK_WINDOW(data->dialog), CUR_SELECT_MODE_CUSTOM, &selectCtx);
 	if( result == GTK_RESPONSE_ACCEPT )
 	{
 	Currency *item = NULL;
@@ -1658,7 +1658,7 @@ struct ui_cur_manage_dialog_data *data;
 GtkWidget *dialog, *content_area, *content_grid, *group_grid, *vbox, *bbox, *tbar;
 GtkWidget *widget, *scrollwin, *treeview;
 GtkToolItem *toolitem;
-gint crow, row, w, h;
+gint crow, row, w, h, dw, dh;
 
 	data = g_malloc0(sizeof(struct ui_cur_manage_dialog_data));
 	if(!data) return NULL;
@@ -1678,7 +1678,11 @@ gint crow, row, w, h;
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
-	gtk_window_set_default_size (GTK_WINDOW(dialog), -1, h/PHI);
+	dh = (h*1.33/PHI);
+	//ratio 1:1
+	dw = (dh * 1) / 1;
+	DB( g_print(" main w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
+	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
 
 	
 	//store our window private data
