@@ -72,8 +72,9 @@ struct ui_cur_edit_dialog_data
 };
 
 enum {
-	CUR_SELECT_MODE_NORMAL,
-	CUR_SELECT_MODE_BASE
+	CUR_SELECT_MODE_BASE,
+	CUR_SELECT_MODE_NOCUSTOM,
+	CUR_SELECT_MODE_CUSTOM,
 };
 
 
