@@ -1001,24 +1001,6 @@ static void ui_flt_manage_set(struct ui_flt_manage_data *data)
 }
 
 
-/*
-**
-*/
-static void ui_flt_manage_clear(GtkWidget *widget, gpointer user_data)
-{
-struct ui_flt_manage_data *data;
-
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW)), "inst_data");
-
-	DB( g_print("(ui_flt_manage) clear\n") );
-
-	filter_reset(data->filter);
-
-	ui_flt_manage_set(data);
-
-}
-
-
 /*
 **
 */
@@ -1439,42 +1421,51 @@ gint i, row;
 gint ui_flt_manage_dialog_new(GtkWindow *parentwindow, Filter *filter, gboolean show_account, gboolean txnmode)
 {
 struct ui_flt_manage_data *data;
-GtkWidget *window, *content, *mainbox, *sidebar, *stack, *page;
-//gint w, h;
+GtkWidget *dialog, *content, *mainbox, *sidebar, *stack, *page, *widget;
+gint w, h, dw, dh;
 
 	data = g_malloc0(sizeof(struct ui_flt_manage_data));
 
 	data->filter = filter;
 
-	window = gtk_dialog_new_with_buttons (_("Edit filter"),
-					    GTK_WINDOW (parentwindow),
-					    0,
-					    _("_Reset"),
-					    55,
-					    _("_Cancel"),
-					    GTK_RESPONSE_REJECT,
-					    _("_OK"),
-					    GTK_RESPONSE_ACCEPT,
-					    NULL);
+	dialog = gtk_dialog_new_with_buttons (_("Edit filter"),
+			GTK_WINDOW (parentwindow),
+			0,	//no flags
+			NULL, //no buttons
+			NULL);
 
-	gtk_window_set_icon_name(GTK_WINDOW (window), ICONNAME_HB_FILTER);
+	if(!txnmode)
+	{
+		widget = gtk_dialog_add_button(GTK_DIALOG(dialog), _("_Reset"),	55);
+		gtk_widget_set_margin_right(widget, SPACING_MEDIUM);
+	}
+
+	gtk_dialog_add_button(GTK_DIALOG(dialog), _("_Cancel"),	GTK_RESPONSE_REJECT);
+	gtk_dialog_add_button(GTK_DIALOG(dialog), _("_OK"),    GTK_RESPONSE_ACCEPT);
+
+
+	//TODO:
+	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_FILTER);
 
 	//set a nice dialog size
-	//gtk_window_get_size(GTK_WINDOW(parentwindow), &w, &h);
-	//gtk_window_set_default_size (GTK_WINDOW(window), -1, 0.8*h);
-
+	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
+	dh = (h*1.33/PHI);
+	//ratio 2:3
+	dw = (dh * 2) / 3;
+	DB( g_print(" main w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
+	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
 
 	//store our window private data
-	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)data);
-	DB( g_print("(ui_flt_manage) window=%p, inst_data=%p\n", window, data) );
+	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
+	DB( g_print("(ui_flt_manage) window=%p, inst_data=%p\n", dialog, data) );
 
-    g_signal_connect (window, "destroy",
-			G_CALLBACK (gtk_widget_destroyed), &window);
+    g_signal_connect (dialog, "destroy",
+			G_CALLBACK (gtk_widget_destroyed), &dialog);
+
+	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 
-	content = gtk_dialog_get_content_area(GTK_DIALOG (window));
 	mainbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (content), mainbox, TRUE, TRUE, 0);
-	//gtk_container_set_border_width (GTK_CONTAINER(mainbox), SPACING_MEDIUM);
 
 	sidebar = gtk_stack_sidebar_new ();
 	gtk_widget_set_margin_bottom(sidebar, SPACING_LARGE);
@@ -1482,9 +1473,11 @@ GtkWidget *window, *content, *mainbox, *sidebar, *stack, *page;
 
 
 	stack = gtk_stack_new ();
-	gtk_stack_set_transition_type (GTK_STACK (stack), GTK_STACK_TRANSITION_TYPE_SLIDE_UP_DOWN);
+	//gtk_stack_set_transition_type (GTK_STACK (stack), GTK_STACK_TRANSITION_TYPE_SLIDE_UP_DOWN);
+	//gtk_stack_set_transition_type (GTK_STACK (stack), GTK_STACK_TRANSITION_TYPE_CROSSFADE);
 	gtk_stack_sidebar_set_stack (GTK_STACK_SIDEBAR (sidebar), GTK_STACK (stack));
-	gtk_container_set_border_width(GTK_CONTAINER(stack), SPACING_LARGE);
+	gtk_container_set_border_width(GTK_CONTAINER(stack), SPACING_MEDIUM);
+
 
 	data->stack = stack;
     gtk_box_pack_start (GTK_BOX (mainbox), stack, TRUE, TRUE, 0);
@@ -1533,11 +1526,11 @@ GtkWidget *window, *content, *mainbox, *sidebar, *stack, *page;
 	}
 
 	
-	//setup, init and show window
+	//setup, init and show dialog
 	ui_flt_manage_setup(data);
 	ui_flt_manage_set(data);
 
-	ui_flt_manage_option_update(window, NULL);
+	ui_flt_manage_option_update(dialog, NULL);
 
 	/* signal connect */
     g_signal_connect (data->CY_option[FILTER_STATUS]  , "changed", G_CALLBACK (ui_flt_manage_option_update), NULL);
@@ -1558,7 +1551,7 @@ GtkWidget *window, *content, *mainbox, *sidebar, *stack, *page;
 
 
 
-	gtk_widget_show_all (window);
+	gtk_widget_show_all (dialog);
 
 	if(!txnmode)
 	{
@@ -1577,7 +1570,7 @@ GtkWidget *window, *content, *mainbox, *sidebar, *stack, *page;
 
 	//while( result == 55 )
 	//{
-		retval = gtk_dialog_run (GTK_DIALOG (window));
+		retval = gtk_dialog_run (GTK_DIALOG (dialog));
 
 		switch (retval)
 	    {
@@ -1585,13 +1578,7 @@ GtkWidget *window, *content, *mainbox, *sidebar, *stack, *page;
 		   //do_application_specific_something ();
 			ui_flt_manage_get(data);
 			break;
-		case 55:
-			ui_flt_manage_clear(window, NULL);
-			ui_flt_manage_get(data);
-			break;
-		default:
-		   //do_nothing_since_dialog_was_cancelled ();
-		   break;
+		//case 55:	reset will be treated in calling dialog
 	    }
 	//}
 
@@ -1603,7 +1590,7 @@ GtkWidget *window, *content, *mainbox, *sidebar, *stack, *page;
 	//g_free(data);
 
 	DB( g_print(" destroy\n") );
-	gtk_widget_destroy (window);
+	gtk_widget_destroy (dialog);
 
 	g_free(data);
 	
