@@ -799,7 +799,8 @@ gchar *string;
 		name = entry->name;
 
 	#if MYDEBUG
-		string = g_strdup_printf ("%d > %s [ft=%d]", entry->key, name, entry->flt_select);
+		//string = g_strdup_printf ("%d > %s [ft=%d]", entry->key, name, entry->flt_select);
+		string = g_strdup_printf ("%d > %s", entry->key, name);
 		g_object_set(renderer, "text", string, NULL);
 		g_free(string);
 	#else
@@ -1610,7 +1611,7 @@ struct ui_pay_manage_dialog_data *data;
 GtkWidget *dialog, *content, *mainvbox, *vbox, *bbox, *treeview, *scrollwin, *table;
 GtkWidget *menu, *menuitem, *widget, *image, *searchbar, *addreveal, *tbar;
 GtkToolItem *toolitem;
-gint w, h, row;
+gint w, h, dw, dh, row;
 
 	data = g_malloc0(sizeof(struct ui_pay_manage_dialog_data));
 	if(!data) return NULL;
@@ -1621,11 +1622,13 @@ gint w, h, row;
 					    _("_Close"), GTK_RESPONSE_ACCEPT,
 					    NULL);
 
-	/*dialog = g_object_new (GTK_TYPE_DIALOG, "use-header-bar", TRUE, NULL);
+	/*
+	dialog = g_object_new (GTK_TYPE_DIALOG, "use-header-bar", TRUE, NULL);
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Manage Payees"));
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW(GLOBALS->mainwindow));
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 	*/
+
 	//gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 	
 	data->dialog = dialog;
@@ -1635,8 +1638,11 @@ gint w, h, row;
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
-	gtk_window_set_default_size (GTK_WINDOW(dialog), -1, h/PHI);
-
+	dh = (h*1.33/PHI);
+	//ratio 2:3
+	dw = (dh * 2) / 3;
+	DB( g_print(" main w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
+	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
 	
 	//store our dialog private data
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
