@@ -829,6 +829,20 @@ gboolean sensitive;
 }
 
 
+static void defpref_gtkoverridetoggle(GtkWidget *widget, gpointer user_data)
+{
+struct defpref_data *data;
+gboolean sensitive;
+
+	DB( g_print("\n[ui-pref] gtk override toggle\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	sensitive = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_gtk_override));
+	gtk_widget_set_sensitive(data->NB_gtk_fontsize, sensitive);
+}
+
+
 static void defpref_backuptoggle(GtkWidget *widget, gpointer user_data)
 {
 struct defpref_data *data;
@@ -961,6 +975,10 @@ GdkRGBA rgba;
 	else
 		gtk_combo_box_set_active (GTK_COMBO_BOX(data->CY_language), 0);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_toolbar), PREFS->toolbar_style);
+
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_gtk_override), PREFS->gtk_override);
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_gtk_fontsize), PREFS->gtk_fontsize);
+
 	//gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_image_size), PREFS->image_size);
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_custom_colors), PREFS->custom_colors);
@@ -970,6 +988,7 @@ GdkRGBA rgba;
 	gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(data->CP_inc_color), &rgba);
 	gdk_rgba_parse(&rgba, PREFS->color_warn);
 	gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(data->CP_warn_color), &rgba);
+
 	//gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_ruleshint), PREFS->rules_hint);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_gridlines), PREFS->grid_lines);
 
@@ -1072,6 +1091,9 @@ const gchar *lang;
 	PREFS->toolbar_style = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_toolbar));
 	//PREFS->image_size = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_image_size));
 
+	PREFS->gtk_override = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_gtk_override));
+	PREFS->gtk_fontsize = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_gtk_fontsize));
+
 	PREFS->custom_colors = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_custom_colors));
 	gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(data->CP_exp_color), &rgba);
 	g_free(PREFS->color_exp);
@@ -1784,13 +1806,6 @@ gint crow, row;
 	data->CY_toolbar = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
-
-
-
-
-
-
-
 	row++;
 	//widget = gtk_check_button_new_with_mnemonic (_("Enable rows in alternating colors"));
 	//data->CM_ruleshint = widget;
@@ -1800,6 +1815,27 @@ gint crow, row;
 	data->CY_gridlines = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
+	// group :: GTK override
+    group_grid = gtk_grid_new ();
+	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
+	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
+	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
+	
+	label = make_label_group(_("Gtk settings"));
+	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
+
+	row = 1;
+	widget = gtk_check_button_new_with_mnemonic (_("Override"));
+	data->CM_gtk_override = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
+	
+	row++;	
+	label = make_label(_("Font _size:"), 0, 0.5);
+	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
+	widget = make_numeric(label, 8, 16);
+	data->NB_gtk_fontsize = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
 	// group :: Amount colors
     group_grid = gtk_grid_new ();
 	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
@@ -2333,6 +2369,8 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 	//connect all our signals
 	g_signal_connect (window, "destroy", G_CALLBACK (gtk_widget_destroyed), &window);
 
+	g_signal_connect (data->CM_gtk_override, "toggled", G_CALLBACK (defpref_gtkoverridetoggle), NULL);
+
 	g_signal_connect (data->CM_bak_is_automatic, "toggled", G_CALLBACK (defpref_backuptoggle), NULL);
 
 	
@@ -2376,6 +2414,7 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 
 	defpref_set(data);
 
+	defpref_gtkoverridetoggle(window, NULL);
 	defpref_colortoggle(window, NULL);
 	defpref_eurotoggle(window, NULL);
 
@@ -2411,7 +2450,7 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 
 				defpref_get(data);
 				homebank_pref_save();
-				ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_BALANCE+UF_VISUAL));
+				ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_VISUAL));
 
 				DB( g_print("old='%s' new='%s'\n", old_lang, PREFS->language) );
 				
