@@ -50,6 +50,8 @@ struct defpref_data
 
 	GtkWidget	*CY_language;
 	GtkWidget	*CY_toolbar;
+	GtkWidget	*CM_gtk_override;
+	GtkWidget	*NB_gtk_fontsize;
 
 
 
