@@ -329,6 +329,7 @@ static void ui_split_dialog_cb_eval_split(GtkWidget *widget, gpointer user_data)
 struct ui_split_dialog_data *data;
 gboolean sensitive;
 gdouble amount;
+const gchar *txt;
 guint count;
 	
 	DB( g_print("\n[ui_split_dialog] eval split\n") );
@@ -343,7 +344,11 @@ guint count;
 	sensitive = ( count >= TXN_MAX_SPLIT ) ? FALSE : TRUE;
 	gtk_widget_set_sensitive (data->BT_add, sensitive);
 
-	DB( g_print(" - txt='%s' amt=%.2f, nbsplit=%d\n", gtk_entry_get_text(GTK_ENTRY(data->ST_amount)), amount, count) );
+	//#5.4.3 get a sign -/+
+	txt = gtk_entry_get_text(GTK_ENTRY(data->ST_amount));
+	data->amtsigned = (*txt == '-' || *txt == '+') ? TRUE : FALSE;
+
+	DB( g_print(" - txt='%s' amt=%.2f, signed=%d, nbsplit=%d\n", txt, amount, data->amtsigned, count) );
 
 }
 
@@ -557,14 +562,23 @@ gdouble amount;
 	count = da_splits_length (data->tmp_splits);
 	if( count <= TXN_MAX_SPLIT )
 	{
+	gboolean amtsigned;
+	
 		split = da_split_malloc ();
+		//preserve amtsigned, resetted with gtk_spin_button_update
+		amtsigned = data->amtsigned;
 		gtk_spin_button_update (GTK_SPIN_BUTTON(data->ST_amount));
 		amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
 		if(amount)
 		{
-			//#1848604 force sign according txn type
-			if( hb_amount_type_match(amount, data->txntype) == FALSE)
-				amount *= -1;
+			//#5.4.3 force sign only if the input has no sign
+			//#1880386 	wish: revert ease to combine expense/income in splits dialog
+			if( amtsigned == FALSE )
+			{
+				//#1848604 force sign according txn type
+				if( hb_amount_type_match(amount, data->txntype) == FALSE)
+					amount *= -1;
+			}
 
 			split->amount = amount;
 			split->kcat = ui_cat_comboboxentry_get_key_add_new(GTK_COMBO_BOX(data->PO_cat));
@@ -582,12 +596,13 @@ gdouble amount;
 
 			ui_split_dialog_compute (widget, data);
 		}
+		// 0 amount not allowed into splits
 		else
 		{
-			//todo: msg max number reached
 			da_split_free(split);
 		}
 	}
+	//todo: msg max number reached
 	
 	ui_split_dialog_edit_end(widget, user_data);
 	ui_split_dialog_update (widget, user_data);
@@ -708,7 +723,8 @@ gboolean valid;
 	//if split sum sign do not match
 	if( hb_amount_type_match(data->sumsplit, data->txntype) == FALSE )
 	{
-		sensitive = FALSE;
+		//#1885413 enable sign invert from split dialog
+		//sensitive = FALSE;
 		gtk_widget_show_all(data->IB_errtype);
 		//#GTK+710888: hack waiting a GTK fix 
 		gtk_widget_queue_resize (data->IB_errtype);
