@@ -55,6 +55,7 @@ struct ui_split_dialog_data
 	gint		txntype;
 	 
 	gdouble		amount;
+	gboolean	amtsigned;
 	gdouble		sumsplit;
 	gdouble		remsplit;
 
@@ -78,6 +79,9 @@ void ui_split_dialog_inactiveline(GtkWidget *widget, gpointer user_data);
 void ui_split_dialog_activeline(GtkWidget *widget, gpointer user_data);
 void ui_split_dialog_get(struct ui_split_dialog_data *data);
 void ui_split_dialog_set(struct ui_split_dialog_data *data);
+
 GtkWidget *ui_split_dialog (GtkWidget *parent, GPtrArray **src_splits,  gint txntype, gdouble amount, void (update_callbackFunction(GtkWidget*, gdouble)));
 
+GtkWidget *ui_split_view_dialog (GtkWidget *parent, Transaction *ope);
+
 #endif
