@@ -40,9 +40,18 @@ extern struct Preferences *PREFS;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-//TODO: still used in rep_time
+//TODO: ui_tag_combobox still used in rep_time
+
+
+guint32
+ui_tag_combobox_get_key(GtkComboBoxText *combobox)
+{
+	return hbtk_combo_box_get_active_id(combobox);
+}
+
+
 void
-ui_tag_combobox_populate(GtkComboBoxText *combobox)
+ui_tag_combobox_populate_except(GtkComboBoxText *combobox, guint except_key)
 {
 GList *ltag, *list;
 	
@@ -54,15 +63,26 @@ GList *ltag, *list;
 	while (list != NULL)
 	{
 	Tag *item = list->data;
-	
-		DB( g_print(" populate: %d\n", item->key) );
 
-		hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combobox), item->key, item->name);
+		if( item->key != except_key )
+		{
+
+			DB( g_print(" populate: %d\n", item->key) );
+
+			hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combobox), item->key, item->name);
+		}
+
 		list = g_list_next(list);
 	}
 
 	g_list_free(ltag);
-	
+}
+
+
+void
+ui_tag_combobox_populate(GtkComboBoxText *combobox)
+{
+	ui_tag_combobox_populate_except(combobox, -1);
 }
 
 
@@ -574,8 +594,123 @@ guint32 key;
 }
 
 
+static void ui_tag_manage_dialog_merge(GtkWidget *widget, gpointer user_data)
+{
+struct ui_tag_manage_dialog_data *data;
+GtkWidget *dialog, *content, *mainvbox;
+GtkWidget *getwidget, *togglebutton;
+GtkTreeSelection *selection;
+GtkTreeModel *model;
+GtkTreeIter iter;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+	DB( g_print("(ui_tag_manage_dialog) merge %p\n", data) );
+
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_tag));
+	//if true there is a selected node
+	if (gtk_tree_selection_get_selected(selection, &model, &iter))
+	{
+	Tag *srctag;
+	gchar *title;
+	gchar *secondtext;
+
+		gtk_tree_model_get(model, &iter, LST_DEFTAG_DATAS, &srctag, -1);
+
+		title = g_strdup_printf (
+			_("Merge tag '%s'"), srctag->name);
+		
+		dialog = gtk_message_dialog_new (GTK_WINDOW (data->dialog),
+			                              GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+			                              GTK_MESSAGE_WARNING,
+			                              GTK_BUTTONS_NONE,
+			                              title,
+		                             	  NULL
+			                              );
+
+		gtk_dialog_add_buttons (GTK_DIALOG(dialog),
+				_("_Cancel"), GTK_RESPONSE_CANCEL,
+				_("Merge"), GTK_RESPONSE_OK,
+				NULL);
+
+		gtk_dialog_set_default_response(GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
+
+		content = gtk_message_dialog_get_message_area(GTK_MESSAGE_DIALOG (dialog));
+		mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
+		gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
+
+		secondtext = _("Transactions assigned to this tag,\n"
+			  "will be moved to the tag selected below.");
+
+		g_object_set(GTK_MESSAGE_DIALOG (dialog), "secondary-text", secondtext, NULL);
+		g_free(title);
+
+		getwidget = ui_tag_combobox_new(NULL);
+		gtk_box_pack_start (GTK_BOX (mainvbox), getwidget, FALSE, FALSE, 0);
+
+		secondtext = g_strdup_printf (
+			_("_Delete the tag '%s'"), srctag->name);
+		togglebutton = gtk_check_button_new_with_mnemonic(secondtext);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(togglebutton), TRUE);
+		g_free(secondtext);
+		gtk_box_pack_start (GTK_BOX (mainvbox), togglebutton, FALSE, FALSE, 0);
+
+		//setup 
+
+		ui_tag_combobox_populate_except(GTK_COMBO_BOX_TEXT(getwidget), srctag->key);
+		gtk_widget_grab_focus (getwidget);
+
+		gtk_widget_show_all(mainvbox);
+		
+		//wait for the user
+		gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+
+		if(result == GTK_RESPONSE_OK)
+		{
+		GtkTreeModel *model;
+		Tag *newtag;
+		guint dsttagkey;
+
+			model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_tag));
+			gtk_list_store_clear (GTK_LIST_STORE(model));
+
+			dsttagkey = ui_tag_combobox_get_key(GTK_COMBO_BOX_TEXT(getwidget));
+
+			tag_move(srctag->key, dsttagkey);
+
+			newtag = da_tag_get(dsttagkey);
+
+			//#1771720: update count
+			newtag->usage_count += srctag->usage_count;
+			srctag->usage_count = 0;
+
+			// add the new tagee to listview
+			if(newtag)
+				ui_tag_listview_add(GTK_TREE_VIEW(data->LV_tag), newtag);
+
+			// delete the old tagee
+			if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton)) )
+			{
+				DB( g_print(" -> delete %d '%s'\n", srctag->key, srctag->name ) );
+
+				ui_tag_listview_remove_selected(GTK_TREE_VIEW(data->LV_tag));
+				da_tag_delete(srctag->key);
+			}
+
+
+			data->change++;
+
+			ui_tag_listview_populate(data->LV_tag, 0);
+		}
+
+		// cleanup and destroy
+		gtk_widget_destroy (dialog);
+	}
+
+}
+
+
 /*
-** delete the selected payee to our treeview and temp GList
+** delete the selected tag to our treeview and temp GList
 */
 static void ui_tag_manage_dialog_delete(GtkWidget *widget, gpointer user_data)
 {
@@ -601,8 +736,8 @@ gint result;
 
 		if( item->usage_count > 0 )
 		{
-			secondtext = _("This payee is used.\n"
-			    "Any transaction using that payee will be set to (no payee)");
+			secondtext = _("This tag is used.\n"
+			    "That tag will be deleted from any transaction using it.");
 		}
 
 		result = ui_dialog_msg_confirm_alert(
@@ -616,7 +751,7 @@ gint result;
 
 		if( result == GTK_RESPONSE_OK )
 		{
-			payee_move(key, 0);
+			tag_move(key, 0);
 			ui_tag_listview_remove_selected(GTK_TREE_VIEW(data->LV_tag));
 			da_tag_delete(key);
 			data->change++;
@@ -640,6 +775,7 @@ guint32 key;
 
 	sensitive = (key > 0) ? TRUE : FALSE;
 	gtk_widget_set_sensitive(data->BT_edit, sensitive);
+	gtk_widget_set_sensitive(data->BT_merge, sensitive);
 	gtk_widget_set_sensitive(data->BT_delete, sensitive);
 
 }
@@ -678,7 +814,7 @@ GtkWidget *ui_tag_manage_dialog (void)
 struct ui_tag_manage_dialog_data *data;
 GtkWidget *dialog, *content, *mainvbox, *box, *bbox, *tbar, *treeview, *scrollwin, *table, *addreveal;
 GtkToolItem *toolitem;
-gint w, h, row;
+gint w, h, dw, dh, row;
 
 	data = g_malloc0(sizeof(struct ui_tag_manage_dialog_data));
 	if(!data) return NULL;
@@ -703,9 +839,13 @@ gint w, h, row;
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
-	gtk_window_set_default_size (GTK_WINDOW(dialog), -1, h/PHI);
+	dh = (h*1.33/PHI);
+	//ratio 3:2
+	dw = (dh * 2) / 3;
+	DB( g_print(" main w=%d h=%d => diag w=%d h=%d\n", w, h, dw, dh) );
+	gtk_window_set_default_size (GTK_WINDOW(dialog), dw, dh);
+
 
-	
 	//store our dialog private data
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
 	DB( g_print("(ui_tag_manage_dialog) dialog=%p, inst_data=%p\n", dialog, data) );
@@ -765,6 +905,9 @@ gint w, h, row;
 	data->BT_edit = make_image_button(ICONNAME_LIST_EDIT, _("Edit"));
 	gtk_container_add (GTK_CONTAINER (bbox), data->BT_edit);
 
+	data->BT_merge = make_image_button(ICONNAME_HB_LIST_MERGE, _("Move/Merge"));
+	gtk_container_add (GTK_CONTAINER (bbox), data->BT_merge);
+
 	data->BT_delete = make_image_button(ICONNAME_LIST_DELETE, _("Delete"));
 	gtk_container_add (GTK_CONTAINER (bbox), data->BT_delete);
 
@@ -788,6 +931,7 @@ gint w, h, row;
 	g_signal_connect (GTK_TREE_VIEW(data->LV_tag), "row-activated", G_CALLBACK (ui_tag_manage_dialog_onRowActivated), NULL);
 
 	g_signal_connect (G_OBJECT (data->BT_edit), "clicked", G_CALLBACK (ui_tag_manage_dialog_edit), NULL);
+	g_signal_connect (G_OBJECT (data->BT_merge), "clicked", G_CALLBACK (ui_tag_manage_dialog_merge), NULL);
 	g_signal_connect (G_OBJECT (data->BT_delete), "clicked", G_CALLBACK (ui_tag_manage_dialog_delete), NULL);
 
 	//setup, init and show dialog
