@@ -456,7 +456,7 @@ gboolean change;
 		
 		//#1872329 fill-in cheque if condition match
 		deftransaction_set_cheque(widget, NULL);
-		
+
 		DB( g_print(" - call warnsign\n") );
 		deftransaction_update_warnsign(widget, NULL);
 	}
@@ -559,6 +559,7 @@ gint type;
 void deftransaction_set_amount_from_split(GtkWidget *widget, gdouble amount)
 {
 struct deftransaction_data *data;
+gint type;
 
 	DB( g_print("\n[ui-transaction] set_amount_from_split\n") );
 
@@ -566,11 +567,16 @@ struct deftransaction_data *data;
 
 	DB( g_print("- amount=%.2f\n", amount) );
 
+	//#1885413 enable sign invert from split dialog
+	type = (amount < 0.0) ?	TXN_TYPE_EXPENSE : TXN_TYPE_INCOME;
+	hbtk_radio_button_block_by_func(GTK_CONTAINER(data->RA_type), G_CALLBACK(deftransaction_cb_type_toggled), NULL);
+	hbtk_radio_button_set_active(GTK_CONTAINER(data->RA_type), type);
+	hbtk_radio_button_unblock_by_func(GTK_CONTAINER(data->RA_type), G_CALLBACK(deftransaction_cb_type_toggled), NULL);
+
 	data->ope->amount = amount;
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), amount);
 	
 	deftransaction_update(widget, NULL);
-	
 }
 
 
@@ -716,8 +722,8 @@ gint type, active;
 	if(active == 1) entry->flags |= OF_CHEQ2;
 
 	//active = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_amount));
-	active = entry->amount > 0 ? TRUE : FALSE;
-	if(active == TRUE) entry->flags |= OF_INCOME;
+	//we keep this in cas the user want to force the type
+	da_transaction_set_flag(entry);
 
 }
 
@@ -852,7 +858,7 @@ Account *acc;
 			}
 		}
 
-		//1638035: manage account change
+		//#1638035: manage account change
 		if( old_txn->kacc != new_txn->kacc )
 		{
 			//todo: maybe we should restrict this also to same currency account
@@ -860,7 +866,13 @@ Account *acc;
 			transaction_acc_move(new_txn, old_txn->kacc, new_txn->kacc);
 		}
 	}
-	
+	//#1883403 we may have changed the split amount but if we cancel it must be restored
+	else
+	{
+		if( old_txn->flags & OF_SPLIT )
+			new_txn->amount = old_txn->amount;
+	}
+
 	deftransaction_dispose(dialog, NULL);
 	gtk_widget_destroy (dialog);
 
