@@ -258,7 +258,12 @@ guint changes;
 		{
 			if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(data->CM_amount)) )
 			{
+				//#1874548 update the balances as well
+				account_balances_sub(txn);	
 				txn->amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
+				account_balances_add(txn);
+				//5.4.2 income flag fix
+				da_transaction_set_flag(txn);
 				change = TRUE;
 			}
 		}
