@@ -24,13 +24,6 @@
 /* = = = = = = = = = = = = = = = = = = = = */
 
 
-gchar *RA_ARC_TYPE[] = { 
-	N_("Scheduled"), 
-	N_("Template"), 
-	NULL
-};
-
-
 gchar *CYA_ASG_FIELD[] = { 
 	N_("Memo"), 
 	N_("Payee"), 
