@@ -162,6 +162,15 @@ gimp_label_set_attributes (GtkLabel *label,
 }
 
 
+void hb_widget_set_margin(GtkWidget *widget, gint margin)
+{
+	gtk_widget_set_margin_start (widget, margin);
+	gtk_widget_set_margin_end (widget, margin);
+	gtk_widget_set_margin_top (widget, margin);
+	gtk_widget_set_margin_bottom (widget, margin);
+}
+
+
 void hb_widget_visible(GtkWidget *widget, gboolean visible)
 {
 	if(!GTK_IS_WIDGET(widget))
@@ -560,7 +569,8 @@ gchar *clntxt;
 			if( g_ascii_isdigit(text[i]) && ( (*position <= dcpos + digits) || dcpos < 0) )
 				goto doinsert;
 
-			if( text[i]=='-' && *position==0 )	/* minus sign only at position 0 */
+			//5.4.3 + sign now authorized
+			if( (text[i]=='-' || text[i]=='+') && *position==0 )	/* -/+ sign only at position 0 */
 				goto doinsert;
 
 			if( dcpos < 0 && (text[i]=='.' || text[i]==',') )	/* decimal separator if not in previous string */
@@ -619,7 +629,9 @@ GtkWidget *make_exchange_rate(GtkWidget *label)
 GtkWidget *spinner;
 GtkAdjustment *adj;
 
-	adj = (GtkAdjustment *) gtk_adjustment_new (0.0, 0.0, 99999, 0.01, 1.0, 0.0);
+	//#1871383 wish: increase exchange rate size
+	//adj = (GtkAdjustment *) gtk_adjustment_new (0.0, 0.0, 99999, 0.01, 1.0, 0.0);
+	adj = (GtkAdjustment *) gtk_adjustment_new (0.0, 0.0, 999999, 0.01, 1.0, 0.0);
 	spinner = gtk_spin_button_new (adj, 1.0, 8);
 	//gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spinner), TRUE);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinner), TRUE);
@@ -710,11 +722,8 @@ GtkWidget *popover;
 	gtk_container_add (GTK_CONTAINER (popover), child);
 	gtk_widget_show (child);
 
-	gtk_widget_set_margin_start (child, SPACING_POPOVER);
-	gtk_widget_set_margin_end (child, SPACING_POPOVER);
-	gtk_widget_set_margin_top (child, SPACING_POPOVER);
-	gtk_widget_set_margin_bottom (child, SPACING_POPOVER);
-
+	hb_widget_set_margin(child, SPACING_POPOVER);
+	
 	return popover;
 }
 
